# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_web.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x61zure/azure_microsoft_web.proto\x12\x1foak9.tython.azure.microsoft_web\x1a\x13shared/shared.proto\"\xd8\x05\n\rMicrosoft_Web\x12R\n\x14hosting_environments\x18\x01 \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_web.HostingEnvironments\x12\x41\n\x0bserverfarms\x18\x02 \x01(\x0b\x32,.oak9.tython.azure.microsoft_web.Serverfarms\x12\x87\x01\n0serverfarms_virtual_network_connections_gateways\x18\x03 \x03(\x0b\x32M.oak9.tython.azure.microsoft_web.ServerfarmsVirtualNetworkConnectionsGateways\x12\x83\x01\n.serverfarms_virtual_network_connections_routes\x18\x04 \x03(\x0b\x32K.oak9.tython.azure.microsoft_web.ServerfarmsVirtualNetworkConnectionsRoutes\x12\x35\n\x05sites\x18\x05 \x01(\x0b\x32&.oak9.tython.azure.microsoft_web.Sites\x12\x41\n\x0csites_config\x18\x06 \x03(\x0b\x32+.oak9.tython.azure.microsoft_web.SiteConfig\x12L\n\x11sites_deployments\x18\x07 \x03(\x0b\x32\x31.oak9.tython.azure.microsoft_web.SitesDeployments\x12X\n\x18sites_host_name_bindings\x18\x08 \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_web.SitesHostNameBindings\"\xb9\x01\n#StaticSitesUserProvidedFunctionApps\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1b\n\x13\x66unction_app_region\x18\x04 \x01(\t\x12 \n\x18\x66unction_app_resource_id\x18\x05 \x01(\t\"\xe8\x01\n%StaticSitesPrivateEndpointConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12j\n%private_link_service_connection_state\x18\x04 \x01(\x0b\x32;.oak9.tython.azure.microsoft_web.PrivateLinkConnectionState\"\x9d\x01\n\x19StaticSitesLinkedBackends\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1b\n\x13\x62\x61\x63kend_resource_id\x18\x04 \x01(\t\x12\x0e\n\x06region\x18\x05 \x01(\t\"\x8a\x01\n\x18StaticSitesCustomDomains\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x19\n\x11validation_method\x18\x04 \x01(\t\"L\n\x11StaticSitesConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xbf\x01\n)StaticSitesBuildsUserProvidedFunctionApps\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1b\n\x13\x66unction_app_region\x18\x04 \x01(\t\x12 \n\x18\x66unction_app_resource_id\x18\x05 \x01(\t\"\xa3\x01\n\x1fStaticSitesBuildsLinkedBackends\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1b\n\x13\x62\x61\x63kend_resource_id\x18\x04 \x01(\t\x12\x0e\n\x06region\x18\x05 \x01(\t\"R\n\x17StaticSitesBuildsConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x84\n\n\x0bStaticSites\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12I\n\x08identity\x18\x02 \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_web.ManagedServiceIdentity\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12!\n\x19\x61llow_config_file_updates\x18\x06 \x01(\x08\x12\x0e\n\x06\x62ranch\x18\x07 \x01(\t\x12T\n\x10\x62uild_properties\x18\x08 \x01(\x0b\x32:.oak9.tython.azure.microsoft_web.StaticSiteBuildProperties\x12#\n\x1b\x65nterprise_grade_cdn_status\x18\t \x01(\t\x12\x10\n\x08provider\x18\n \x01(\t\x12\x1d\n\x15public_network_access\x18\x0b \x01(\t\x12\x18\n\x10repository_token\x18\x0c \x01(\t\x12\x16\n\x0erepository_url\x18\r \x01(\t\x12\"\n\x1astaging_environment_policy\x18\x0e \x01(\t\x12W\n\x13template_properties\x18\x0f \x01(\x0b\x32:.oak9.tython.azure.microsoft_web.StaticSiteTemplateOptions\x12<\n\x03sku\x18\x10 \x01(\x0b\x32/.oak9.tython.azure.microsoft_web.SkuDescription\x12\x44\n\x04tags\x18\x11 \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_web.StaticSites.TagsEntry\x12O\n\x13static_sites_config\x18\x12 \x03(\x0b\x32\x32.oak9.tython.azure.microsoft_web.StaticSitesConfig\x12^\n\x1bstatic_sites_custom_domains\x18\x13 \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_web.StaticSitesCustomDomains\x12y\n)static_sites_private_endpoint_connections\x18\x14 \x03(\x0b\x32\x46.oak9.tython.azure.microsoft_web.StaticSitesPrivateEndpointConnections\x12v\n(static_sites_user_provided_function_apps\x18\x15 \x03(\x0b\x32\x44.oak9.tython.azure.microsoft_web.StaticSitesUserProvidedFunctionApps\x12`\n\x1cstatic_sites_linked_backends\x18\x16 \x03(\x0b\x32:.oak9.tython.azure.microsoft_web.StaticSitesLinkedBackends\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8d\x01\n\x19StaticSiteTemplateOptions\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nis_private\x18\x02 \x01(\x08\x12\r\n\x05owner\x18\x03 \x01(\t\x12\x17\n\x0frepository_name\x18\x04 \x01(\t\x12\x1f\n\x17template_repository_url\x18\x05 \x01(\t\"\x91\x02\n\x19StaticSiteBuildProperties\x12\x19\n\x11\x61pi_build_command\x18\x01 \x01(\t\x12\x14\n\x0c\x61pi_location\x18\x02 \x01(\t\x12\x1d\n\x15\x61pp_artifact_location\x18\x03 \x01(\t\x12\x19\n\x11\x61pp_build_command\x18\x04 \x01(\t\x12\x14\n\x0c\x61pp_location\x18\x05 \x01(\t\x12*\n\"github_action_secret_name_override\x18\x06 \x01(\t\x12\x17\n\x0foutput_location\x18\x07 \x01(\t\x12.\n&skip_github_action_workflow_generation\x18\x08 \x01(\x08\"\xa9\x01\n&SitesVirtualNetworkConnectionsGateways\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tvnet_name\x18\x04 \x01(\t\x12\x17\n\x0fvpn_package_uri\x18\x05 \x01(\t\"\xc6\x02\n\x1eSitesVirtualNetworkConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tcert_blob\x18\x04 \x01(\t\x12\x13\n\x0b\x64ns_servers\x18\x05 \x01(\t\x12\x10\n\x08is_swift\x18\x06 \x01(\x08\x12\x18\n\x10vnet_resource_id\x18\x07 \x01(\t\x12{\n*sites_virtual_network_connections_gateways\x18\x08 \x03(\x0b\x32G.oak9.tython.azure.microsoft_web.SitesVirtualNetworkConnectionsGateways\"\xe3\x02\n\x13SitesSourcecontrols\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0e\n\x06\x62ranch\x18\x04 \x01(\t\x12#\n\x1b\x64\x65ployment_rollback_enabled\x18\x05 \x01(\x08\x12`\n\x1cgit_hub_action_configuration\x18\x06 \x01(\x0b\x32:.oak9.tython.azure.microsoft_web.GitHubActionConfiguration\x12\x19\n\x11is_git_hub_action\x18\x07 \x01(\x08\x12\x1d\n\x15is_manual_integration\x18\x08 \x01(\x08\x12\x14\n\x0cis_mercurial\x18\t \x01(\x08\x12\x10\n\x08repo_url\x18\n \x01(\t\"\xae\x01\n+SitesSlotsVirtualNetworkConnectionsGateways\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tvnet_name\x18\x04 \x01(\t\x12\x17\n\x0fvpn_package_uri\x18\x05 \x01(\t\"\xd7\x02\n#SitesSlotsVirtualNetworkConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tcert_blob\x18\x04 \x01(\t\x12\x13\n\x0b\x64ns_servers\x18\x05 \x01(\t\x12\x10\n\x08is_swift\x18\x06 \x01(\x08\x12\x18\n\x10vnet_resource_id\x18\x07 \x01(\t\x12\x86\x01\n0sites_slots_virtual_network_connections_gateways\x18\x08 \x03(\x0b\x32L.oak9.tython.azure.microsoft_web.SitesSlotsVirtualNetworkConnectionsGateways\"\xe8\x02\n\x18SitesSlotsSourcecontrols\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0e\n\x06\x62ranch\x18\x04 \x01(\t\x12#\n\x1b\x64\x65ployment_rollback_enabled\x18\x05 \x01(\x08\x12`\n\x1cgit_hub_action_configuration\x18\x06 \x01(\x0b\x32:.oak9.tython.azure.microsoft_web.GitHubActionConfiguration\x12\x19\n\x11is_git_hub_action\x18\x07 \x01(\x08\x12\x1d\n\x15is_manual_integration\x18\x08 \x01(\x08\x12\x14\n\x0cis_mercurial\x18\t \x01(\x08\x12\x10\n\x08repo_url\x18\n \x01(\t\"\x8f\x02\n\x19GitHubActionConfiguration\x12Z\n\x12\x63ode_configuration\x18\x01 \x01(\x0b\x32>.oak9.tython.azure.microsoft_web.GitHubActionCodeConfiguration\x12\x64\n\x17\x63ontainer_configuration\x18\x02 \x01(\x0b\x32\x43.oak9.tython.azure.microsoft_web.GitHubActionContainerConfiguration\x12\x1e\n\x16generate_workflow_file\x18\x03 \x01(\x08\x12\x10\n\x08is_linux\x18\x04 \x01(\x08\"p\n\"GitHubActionContainerConfiguration\x12\x12\n\nimage_name\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x12\n\nserver_url\x18\x03 \x01(\t\x12\x10\n\x08username\x18\x04 \x01(\t\"O\n\x1dGitHubActionCodeConfiguration\x12\x15\n\rruntime_stack\x18\x01 \x01(\t\x12\x17\n\x0fruntime_version\x18\x02 \x01(\t\"a\n\x18SitesSlotsSiteextensions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xa6\x01\n\x1cSitesSlotsPublicCertificates\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04\x62lob\x18\x04 \x01(\t\x12#\n\x1bpublic_certificate_location\x18\x05 \x01(\t\"\xe7\x01\n$SitesSlotsPrivateEndpointConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12j\n%private_link_service_connection_state\x18\x04 \x01(\x0b\x32;.oak9.tython.azure.microsoft_web.PrivateLinkConnectionState\"\xd7\x01\n\x17SitesSlotsPrivateAccess\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x04 \x01(\x08\x12V\n\x10virtual_networks\x18\x05 \x03(\x0b\x32<.oak9.tython.azure.microsoft_web.PrivateAccessVirtualNetwork\"\xe7\x02\n\x17SitesSlotsPremieraddons\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x19\n\x11marketplace_offer\x18\x05 \x01(\t\x12\x1d\n\x15marketplace_publisher\x18\x06 \x01(\t\x12\x0f\n\x07product\x18\x07 \x01(\t\x12\x0b\n\x03sku\x18\x08 \x01(\t\x12\x0e\n\x06vendor\x18\t \x01(\t\x12P\n\x04tags\x18\n \x03(\x0b\x32\x42.oak9.tython.azure.microsoft_web.SitesSlotsPremieraddons.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa3\x01\n\x17SitesSlotsNetworkConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1a\n\x12subnet_resource_id\x18\x04 \x01(\t\x12\x17\n\x0fswift_supported\x18\x05 \x01(\x08\"\xa7\x03\n\x1dSitesSlotsInstancesExtensions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x61pp_offline\x18\x04 \x01(\x08\x12\x19\n\x11\x63onnection_string\x18\x05 \x01(\t\x12\x0f\n\x07\x64\x62_type\x18\x06 \x01(\t\x12\x13\n\x0bpackage_uri\x18\x07 \x01(\t\x12i\n\x0eset_parameters\x18\x08 \x03(\x0b\x32Q.oak9.tython.azure.microsoft_web.SitesSlotsInstancesExtensions.SetParametersEntry\x12#\n\x1bset_parameters_xml_file_uri\x18\t \x01(\t\x12\x15\n\rskip_app_data\x18\n \x01(\x08\x1a\x34\n\x12SetParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb6\x02\n*SitesSlotsHybridConnectionNamespacesRelays\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x10\n\x08hostname\x18\x04 \x01(\t\x12\x0c\n\x04port\x18\x05 \x01(\x05\x12\x15\n\rrelay_arm_uri\x18\x06 \x01(\t\x12\x12\n\nrelay_name\x18\x07 \x01(\t\x12\x15\n\rsend_key_name\x18\x08 \x01(\t\x12\x16\n\x0esend_key_value\x18\t \x01(\t\x12\x1d\n\x15service_bus_namespace\x18\n \x01(\t\x12\x1a\n\x12service_bus_suffix\x18\x0b \x01(\t\"\x98\x02\n\x1aSitesSlotsHybridconnection\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x62iztalk_uri\x18\x04 \x01(\t\x12 \n\x18\x65ntity_connection_string\x18\x05 \x01(\t\x12\x13\n\x0b\x65ntity_name\x18\x06 \x01(\t\x12\x10\n\x08hostname\x18\x07 \x01(\t\x12\x0c\n\x04port\x18\x08 \x01(\x05\x12\"\n\x1aresource_connection_string\x18\t \x01(\t\x12\x15\n\rresource_type\x18\n \x01(\t\"\xba\x02\n\x1aSitesSlotsHostNameBindings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1b\n\x13\x61zure_resource_name\x18\x04 \x01(\t\x12\x1b\n\x13\x61zure_resource_type\x18\x05 \x01(\t\x12(\n custom_host_name_dns_record_type\x18\x06 \x01(\t\x12\x11\n\tdomain_id\x18\x07 \x01(\t\x12\x16\n\x0ehost_name_type\x18\x08 \x01(\t\x12\x11\n\tsite_name\x18\t \x01(\t\x12\x11\n\tssl_state\x18\n \x01(\t\x12\x12\n\nthumbprint\x18\x0b \x01(\t\"o\n\x17SitesSlotsFunctionsKeys\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xc1\x05\n\x13SitesSlotsFunctions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12P\n\x06\x63onfig\x18\x04 \x03(\x0b\x32@.oak9.tython.azure.microsoft_web.SitesSlotsFunctions.ConfigEntry\x12\x13\n\x0b\x63onfig_href\x18\x05 \x01(\t\x12N\n\x05\x66iles\x18\x06 \x03(\x0b\x32?.oak9.tython.azure.microsoft_web.SitesSlotsFunctions.FilesEntry\x12\x17\n\x0f\x66unction_app_id\x18\x07 \x01(\t\x12\x0c\n\x04href\x18\x08 \x01(\t\x12\x1b\n\x13invoke_url_template\x18\t \x01(\t\x12\x13\n\x0bis_disabled\x18\n \x01(\x08\x12\x10\n\x08language\x18\x0b \x01(\t\x12\x13\n\x0bscript_href\x18\x0c \x01(\t\x12\x1d\n\x15script_root_path_href\x18\r \x01(\t\x12\x19\n\x11secrets_file_href\x18\x0e \x01(\t\x12\x11\n\ttest_data\x18\x0f \x01(\t\x12\x16\n\x0etest_data_href\x18\x10 \x01(\t\x12\\\n\x1asites_slots_functions_keys\x18\x11 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_web.SitesSlotsFunctionsKeys\x1a-\n\x0b\x43onfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a,\n\nFilesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x95\x03\n\x14SitesSlotsExtensions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x61pp_offline\x18\x04 \x01(\x08\x12\x19\n\x11\x63onnection_string\x18\x05 \x01(\t\x12\x0f\n\x07\x64\x62_type\x18\x06 \x01(\t\x12\x13\n\x0bpackage_uri\x18\x07 \x01(\t\x12`\n\x0eset_parameters\x18\x08 \x03(\x0b\x32H.oak9.tython.azure.microsoft_web.SitesSlotsExtensions.SetParametersEntry\x12#\n\x1bset_parameters_xml_file_uri\x18\t \x01(\t\x12\x15\n\rskip_app_data\x18\n \x01(\x08\x1a\x34\n\x12SetParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x87\x01\n$SitesSlotsDomainOwnershipIdentifiers\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\"\x8c\x02\n\x15SitesSlotsDeployments\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0e\n\x06\x61\x63tive\x18\x04 \x01(\x08\x12\x0e\n\x06\x61uthor\x18\x05 \x01(\t\x12\x14\n\x0c\x61uthor_email\x18\x06 \x01(\t\x12\x10\n\x08\x64\x65ployer\x18\x07 \x01(\t\x12\x0f\n\x07\x64\x65tails\x18\x08 \x01(\t\x12\x10\n\x08\x65nd_time\x18\t \x01(\t\x12\x0f\n\x07message\x18\n \x01(\t\x12\x12\n\nstart_time\x18\x0b \x01(\t\x12\x0e\n\x06status\x18\x0c \x01(\x05\"K\n\x10SitesSlotsConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"g\n,SitesSlotsBasicPublishingCredentialsPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x98\x17\n\nSitesSlots\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12L\n\x11\x65xtended_location\x18\x02 \x01(\x0b\x32\x31.oak9.tython.azure.microsoft_web.ExtendedLocation\x12I\n\x08identity\x18\x03 \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_web.ManagedServiceIdentity\x12\x0c\n\x04kind\x18\x04 \x01(\t\x12\x10\n\x08location\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x1f\n\x17\x63lient_affinity_enabled\x18\x07 \x01(\x08\x12\x1b\n\x13\x63lient_cert_enabled\x18\x08 \x01(\x08\x12#\n\x1b\x63lient_cert_exclusion_paths\x18\t \x01(\t\x12\x18\n\x10\x63lient_cert_mode\x18\n \x01(\t\x12\x42\n\x0c\x63loning_info\x18\x0b \x01(\x0b\x32,.oak9.tython.azure.microsoft_web.CloningInfo\x12\x16\n\x0e\x63ontainer_size\x18\x0c \x01(\x05\x12%\n\x1d\x63ustom_domain_verification_id\x18\r \x01(\t\x12\x1f\n\x17\x64\x61ily_memory_time_quota\x18\x0e \x01(\x05\x12\x0f\n\x07\x65nabled\x18\x0f \x01(\x08\x12_\n\x1bhosting_environment_profile\x18\x10 \x01(\x0b\x32:.oak9.tython.azure.microsoft_web.HostingEnvironmentProfile\x12\x1b\n\x13host_names_disabled\x18\x11 \x01(\x08\x12O\n\x14host_name_ssl_states\x18\x12 \x03(\x0b\x32\x31.oak9.tython.azure.microsoft_web.HostNameSslState\x12\x12\n\nhttps_only\x18\x13 \x01(\x08\x12\x0f\n\x07hyper_v\x18\x14 \x01(\x08\x12\x10\n\x08is_xenon\x18\x15 \x01(\x08\x12$\n\x1ckey_vault_reference_identity\x18\x16 \x01(\t\x12\x1d\n\x15public_network_access\x18\x17 \x01(\t\x12\x17\n\x0fredundancy_mode\x18\x18 \x01(\t\x12\x10\n\x08reserved\x18\x19 \x01(\x08\x12\x1d\n\x15scm_site_also_stopped\x18\x1a \x01(\x08\x12\x16\n\x0eserver_farm_id\x18\x1b \x01(\t\x12@\n\x0bsite_config\x18\x1c \x01(\x0b\x32+.oak9.tython.azure.microsoft_web.SiteConfig\x12 \n\x18storage_account_required\x18\x1d \x01(\x08\x12!\n\x19virtual_network_subnet_id\x18\x1e \x01(\t\x12\"\n\x1avnet_content_share_enabled\x18\x1f \x01(\x08\x12\x1f\n\x17vnet_image_pull_enabled\x18  \x01(\x08\x12\x1e\n\x16vnet_route_all_enabled\x18! \x01(\x08\x12\x43\n\x04tags\x18\" \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_web.SitesSlots.TagsEntry\x12\x88\x01\n1sites_slots_basic_publishing_credentials_policies\x18# \x03(\x0b\x32M.oak9.tython.azure.microsoft_web.SitesSlotsBasicPublishingCredentialsPolicies\x12M\n\x12sites_slots_config\x18$ \x03(\x0b\x32\x31.oak9.tython.azure.microsoft_web.SitesSlotsConfig\x12W\n\x17sites_slots_deployments\x18% \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_web.SitesSlotsDeployments\x12w\n(sites_slots_domain_ownership_identifiers\x18& \x03(\x0b\x32\x45.oak9.tython.azure.microsoft_web.SitesSlotsDomainOwnershipIdentifiers\x12U\n\x16sites_slots_extensions\x18\' \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_web.SitesSlotsExtensions\x12S\n\x15sites_slots_functions\x18( \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_web.SitesSlotsFunctions\x12\x63\n\x1esites_slots_host_name_bindings\x18) \x03(\x0b\x32;.oak9.tython.azure.microsoft_web.SitesSlotsHostNameBindings\x12\x61\n\x1csites_slots_hybridconnection\x18* \x03(\x0b\x32;.oak9.tython.azure.microsoft_web.SitesSlotsHybridconnection\x12\\\n\x1asites_slots_network_config\x18+ \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_web.SitesSlotsNetworkConfig\x12[\n\x19sites_slots_premieraddons\x18, \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_web.SitesSlotsPremieraddons\x12\\\n\x1asites_slots_private_access\x18- \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_web.SitesSlotsPrivateAccess\x12w\n(sites_slots_private_endpoint_connections\x18. \x03(\x0b\x32\x45.oak9.tython.azure.microsoft_web.SitesSlotsPrivateEndpointConnections\x12\x66\n\x1fsites_slots_public_certificates\x18/ \x03(\x0b\x32=.oak9.tython.azure.microsoft_web.SitesSlotsPublicCertificates\x12]\n\x1asites_slots_siteextensions\x18\x30 \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_web.SitesSlotsSiteextensions\x12]\n\x1asites_slots_sourcecontrols\x18\x31 \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_web.SitesSlotsSourcecontrols\x12u\n\'sites_slots_virtual_network_connections\x18\x32 \x03(\x0b\x32\x44.oak9.tython.azure.microsoft_web.SitesSlotsVirtualNetworkConnections\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\\\n\x13SitesSiteextensions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xa1\x01\n\x17SitesPublicCertificates\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04\x62lob\x18\x04 \x01(\t\x12#\n\x1bpublic_certificate_location\x18\x05 \x01(\t\"\xe2\x01\n\x1fSitesPrivateEndpointConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12j\n%private_link_service_connection_state\x18\x04 \x01(\x0b\x32;.oak9.tython.azure.microsoft_web.PrivateLinkConnectionState\"\xd2\x01\n\x12SitesPrivateAccess\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x04 \x01(\x08\x12V\n\x10virtual_networks\x18\x05 \x03(\x0b\x32<.oak9.tython.azure.microsoft_web.PrivateAccessVirtualNetwork\"\x94\x01\n\x1bPrivateAccessVirtualNetwork\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0bresource_id\x18\x03 \x01(\t\x12\x45\n\x07subnets\x18\x04 \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_web.PrivateAccessSubnet\"0\n\x13PrivateAccessSubnet\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xdd\x02\n\x12SitesPremieraddons\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x19\n\x11marketplace_offer\x18\x05 \x01(\t\x12\x1d\n\x15marketplace_publisher\x18\x06 \x01(\t\x12\x0f\n\x07product\x18\x07 \x01(\t\x12\x0b\n\x03sku\x18\x08 \x01(\t\x12\x0e\n\x06vendor\x18\t \x01(\t\x12K\n\x04tags\x18\n \x03(\x0b\x32=.oak9.tython.azure.microsoft_web.SitesPremieraddons.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9e\x01\n\x12SitesNetworkConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1a\n\x12subnet_resource_id\x18\x04 \x01(\t\x12\x17\n\x0fswift_supported\x18\x05 \x01(\x08\"\xec\x01\n\x0cSitesMigrate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12$\n\x1c\x61zurefiles_connection_string\x18\x04 \x01(\t\x12\x18\n\x10\x61zurefiles_share\x18\x05 \x01(\t\x12\"\n\x1a\x62lock_write_access_to_site\x18\x06 \x01(\x08\x12#\n\x1bswitch_site_after_migration\x18\x07 \x01(\x08\"\x9d\x03\n\x18SitesInstancesExtensions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x61pp_offline\x18\x04 \x01(\x08\x12\x19\n\x11\x63onnection_string\x18\x05 \x01(\t\x12\x0f\n\x07\x64\x62_type\x18\x06 \x01(\t\x12\x13\n\x0bpackage_uri\x18\x07 \x01(\t\x12\x64\n\x0eset_parameters\x18\x08 \x03(\x0b\x32L.oak9.tython.azure.microsoft_web.SitesInstancesExtensions.SetParametersEntry\x12#\n\x1bset_parameters_xml_file_uri\x18\t \x01(\t\x12\x15\n\rskip_app_data\x18\n \x01(\x08\x1a\x34\n\x12SetParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb1\x02\n%SitesHybridConnectionNamespacesRelays\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x10\n\x08hostname\x18\x04 \x01(\t\x12\x0c\n\x04port\x18\x05 \x01(\x05\x12\x15\n\rrelay_arm_uri\x18\x06 \x01(\t\x12\x12\n\nrelay_name\x18\x07 \x01(\t\x12\x15\n\rsend_key_name\x18\x08 \x01(\t\x12\x16\n\x0esend_key_value\x18\t \x01(\t\x12\x1d\n\x15service_bus_namespace\x18\n \x01(\t\x12\x1a\n\x12service_bus_suffix\x18\x0b \x01(\t\"\x93\x02\n\x15SitesHybridconnection\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x62iztalk_uri\x18\x04 \x01(\t\x12 \n\x18\x65ntity_connection_string\x18\x05 \x01(\t\x12\x13\n\x0b\x65ntity_name\x18\x06 \x01(\t\x12\x10\n\x08hostname\x18\x07 \x01(\t\x12\x0c\n\x04port\x18\x08 \x01(\x05\x12\"\n\x1aresource_connection_string\x18\t \x01(\t\x12\x15\n\rresource_type\x18\n \x01(\t\"\xb5\x02\n\x15SitesHostNameBindings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1b\n\x13\x61zure_resource_name\x18\x04 \x01(\t\x12\x1b\n\x13\x61zure_resource_type\x18\x05 \x01(\t\x12(\n custom_host_name_dns_record_type\x18\x06 \x01(\t\x12\x11\n\tdomain_id\x18\x07 \x01(\t\x12\x16\n\x0ehost_name_type\x18\x08 \x01(\t\x12\x11\n\tsite_name\x18\t \x01(\t\x12\x11\n\tssl_state\x18\n \x01(\t\x12\x12\n\nthumbprint\x18\x0b \x01(\t\"j\n\x12SitesFunctionsKeys\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xa7\x05\n\x0eSitesFunctions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12K\n\x06\x63onfig\x18\x04 \x03(\x0b\x32;.oak9.tython.azure.microsoft_web.SitesFunctions.ConfigEntry\x12\x13\n\x0b\x63onfig_href\x18\x05 \x01(\t\x12I\n\x05\x66iles\x18\x06 \x03(\x0b\x32:.oak9.tython.azure.microsoft_web.SitesFunctions.FilesEntry\x12\x17\n\x0f\x66unction_app_id\x18\x07 \x01(\t\x12\x0c\n\x04href\x18\x08 \x01(\t\x12\x1b\n\x13invoke_url_template\x18\t \x01(\t\x12\x13\n\x0bis_disabled\x18\n \x01(\x08\x12\x10\n\x08language\x18\x0b \x01(\t\x12\x13\n\x0bscript_href\x18\x0c \x01(\t\x12\x1d\n\x15script_root_path_href\x18\r \x01(\t\x12\x19\n\x11secrets_file_href\x18\x0e \x01(\t\x12\x11\n\ttest_data\x18\x0f \x01(\t\x12\x16\n\x0etest_data_href\x18\x10 \x01(\t\x12Q\n\x14sites_functions_keys\x18\x11 \x03(\x0b\x32\x33.oak9.tython.azure.microsoft_web.SitesFunctionsKeys\x1a-\n\x0b\x43onfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a,\n\nFilesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"J\n\x0fSitesExtensions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x82\x01\n\x1fSitesDomainOwnershipIdentifiers\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\"\x87\x02\n\x10SitesDeployments\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0e\n\x06\x61\x63tive\x18\x04 \x01(\x08\x12\x0e\n\x06\x61uthor\x18\x05 \x01(\t\x12\x14\n\x0c\x61uthor_email\x18\x06 \x01(\t\x12\x10\n\x08\x64\x65ployer\x18\x07 \x01(\t\x12\x0f\n\x07\x64\x65tails\x18\x08 \x01(\t\x12\x10\n\x08\x65nd_time\x18\t \x01(\t\x12\x0f\n\x07message\x18\n \x01(\t\x12\x12\n\nstart_time\x18\x0b \x01(\t\x12\x0e\n\x06status\x18\x0c \x01(\x05\"\x94\x05\n\x0bSitesConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nftps_state\x18\x02 \x01(\t\x12\x19\n\x11health_check_path\x18\x03 \x01(\t\x12\x16\n\x0ehttp20_enabled\x18\x04 \x01(\t\x12\x1c\n\x14http_logging_enabled\x18\x05 \x01(\t\x12\x16\n\x0ejava_container\x18\x06 \x01(\t\x12\x1e\n\x16java_container_version\x18\x07 \x01(\t\x12\x14\n\x0cjava_version\x18\x08 \x01(\t\x12\x18\n\x10linux_fx_version\x18\t \x01(\t\x12\x16\n\x0eload_balancing\x18\n \x01(\t\x12!\n\x19logs_directory_size_limit\x18\x0b \x01(\t\x12\x1d\n\x15managed_pipeline_mode\x18\x0c \x01(\t\x12\x17\n\x0fmin_tls_version\x18\r \x01(\t\x12\x1d\n\x15net_framework_version\x18\x0e \x01(\t\x12\x14\n\x0cnode_version\x18\x0f \x01(\t\x12\x13\n\x0bphp_version\x18\x10 \x01(\t\x12\x1b\n\x13publishing_username\x18\x11 \x01(\t\x12\x16\n\x0epython_version\x18\x12 \x01(\t\x12 \n\x18remote_debugging_enabled\x18\x13 \x01(\t\x12 \n\x18remote_debugging_version\x18\x14 \x01(\t\x12-\n%scm_ip_security_restrictions_use_main\x18\x15 \x01(\t\x12\x1a\n\x12windows_fx_version\x18\x16 \x01(\t\"b\n\'SitesBasicPublishingCredentialsPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf9\x14\n\x05Sites\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12L\n\x11\x65xtended_location\x18\x02 \x01(\x0b\x32\x31.oak9.tython.azure.microsoft_web.ExtendedLocation\x12I\n\x08identity\x18\x03 \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_web.ManagedServiceIdentity\x12\x0c\n\x04kind\x18\x04 \x01(\t\x12\x10\n\x08location\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x1f\n\x17\x63lient_affinity_enabled\x18\x07 \x01(\x08\x12\x1b\n\x13\x63lient_cert_enabled\x18\x08 \x01(\x08\x12#\n\x1b\x63lient_cert_exclusion_paths\x18\t \x01(\t\x12\x18\n\x10\x63lient_cert_mode\x18\n \x01(\t\x12\x42\n\x0c\x63loning_info\x18\x0b \x01(\x0b\x32,.oak9.tython.azure.microsoft_web.CloningInfo\x12\x16\n\x0e\x63ontainer_size\x18\x0c \x01(\x05\x12%\n\x1d\x63ustom_domain_verification_id\x18\r \x01(\t\x12\x1f\n\x17\x64\x61ily_memory_time_quota\x18\x0e \x01(\x05\x12\x0f\n\x07\x65nabled\x18\x0f \x01(\x08\x12_\n\x1bhosting_environment_profile\x18\x10 \x01(\x0b\x32:.oak9.tython.azure.microsoft_web.HostingEnvironmentProfile\x12\x1b\n\x13host_names_disabled\x18\x11 \x01(\x08\x12O\n\x14host_name_ssl_states\x18\x12 \x03(\x0b\x32\x31.oak9.tython.azure.microsoft_web.HostNameSslState\x12\x12\n\nhttps_only\x18\x13 \x01(\x08\x12\x0f\n\x07hyper_v\x18\x14 \x01(\x08\x12\x10\n\x08is_xenon\x18\x15 \x01(\x08\x12$\n\x1ckey_vault_reference_identity\x18\x16 \x01(\t\x12\x1d\n\x15public_network_access\x18\x17 \x01(\t\x12\x17\n\x0fredundancy_mode\x18\x18 \x01(\t\x12\x10\n\x08reserved\x18\x19 \x01(\x08\x12\x1d\n\x15scm_site_also_stopped\x18\x1a \x01(\x08\x12\x16\n\x0eserver_farm_id\x18\x1b \x01(\t\x12@\n\x0bsite_config\x18\x1c \x01(\x0b\x32+.oak9.tython.azure.microsoft_web.SiteConfig\x12 \n\x18storage_account_required\x18\x1d \x01(\x08\x12!\n\x19virtual_network_subnet_id\x18\x1e \x01(\t\x12\"\n\x1avnet_content_share_enabled\x18\x1f \x01(\x08\x12\x1f\n\x17vnet_image_pull_enabled\x18  \x01(\x08\x12\x1e\n\x16vnet_route_all_enabled\x18! \x01(\x08\x12>\n\x04tags\x18\" \x03(\x0b\x32\x30.oak9.tython.azure.microsoft_web.Sites.TagsEntry\x12}\n+sites_basic_publishing_credentials_policies\x18# \x03(\x0b\x32H.oak9.tython.azure.microsoft_web.SitesBasicPublishingCredentialsPolicies\x12l\n\"sites_domain_ownership_identifiers\x18$ \x03(\x0b\x32@.oak9.tython.azure.microsoft_web.SitesDomainOwnershipIdentifiers\x12J\n\x10sites_extensions\x18% \x03(\x0b\x32\x30.oak9.tython.azure.microsoft_web.SitesExtensions\x12H\n\x0fsites_functions\x18& \x03(\x0b\x32/.oak9.tython.azure.microsoft_web.SitesFunctions\x12V\n\x16sites_hybridconnection\x18\' \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_web.SitesHybridconnection\x12\x44\n\rsites_migrate\x18( \x03(\x0b\x32-.oak9.tython.azure.microsoft_web.SitesMigrate\x12Q\n\x14sites_network_config\x18) \x03(\x0b\x32\x33.oak9.tython.azure.microsoft_web.SitesNetworkConfig\x12P\n\x13sites_premieraddons\x18* \x03(\x0b\x32\x33.oak9.tython.azure.microsoft_web.SitesPremieraddons\x12Q\n\x14sites_private_access\x18+ \x03(\x0b\x32\x33.oak9.tython.azure.microsoft_web.SitesPrivateAccess\x12l\n\"sites_private_endpoint_connections\x18, \x03(\x0b\x32@.oak9.tython.azure.microsoft_web.SitesPrivateEndpointConnections\x12[\n\x19sites_public_certificates\x18- \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_web.SitesPublicCertificates\x12R\n\x14sites_siteextensions\x18. \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_web.SitesSiteextensions\x12@\n\x0bsites_slots\x18/ \x03(\x0b\x32+.oak9.tython.azure.microsoft_web.SitesSlots\x12R\n\x14sites_sourcecontrols\x18\x30 \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_web.SitesSourcecontrols\x12j\n!sites_virtual_network_connections\x18\x31 \x03(\x0b\x32?.oak9.tython.azure.microsoft_web.SitesVirtualNetworkConnections\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa1\x15\n\nSiteConfig\x12&\n\x1e\x61\x63r_use_managed_identity_creds\x18\x01 \x01(\x08\x12$\n\x1c\x61\x63r_user_managed_identity_id\x18\x02 \x01(\t\x12\x11\n\talways_on\x18\x03 \x01(\x08\x12J\n\x0e\x61pi_definition\x18\x04 \x01(\x0b\x32\x32.oak9.tython.azure.microsoft_web.ApiDefinitionInfo\x12S\n\x15\x61pi_management_config\x18\x05 \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_web.ApiManagementConfig\x12\x18\n\x10\x61pp_command_line\x18\x06 \x01(\t\x12\x44\n\x0c\x61pp_settings\x18\x07 \x03(\x0b\x32..oak9.tython.azure.microsoft_web.NameValuePair\x12\x19\n\x11\x61uto_heal_enabled\x18\x08 \x01(\x08\x12G\n\x0f\x61uto_heal_rules\x18\t \x01(\x0b\x32..oak9.tython.azure.microsoft_web.AutoHealRules\x12\x1b\n\x13\x61uto_swap_slot_name\x18\n \x01(\t\x12\x65\n\x16\x61zure_storage_accounts\x18\x0b \x03(\x0b\x32\x45.oak9.tython.azure.microsoft_web.SiteConfig.AzureStorageAccountsEntry\x12K\n\x12\x63onnection_strings\x18\x0c \x03(\x0b\x32/.oak9.tython.azure.microsoft_web.ConnStringInfo\x12;\n\x04\x63ors\x18\r \x01(\x0b\x32-.oak9.tython.azure.microsoft_web.CorsSettings\x12\x19\n\x11\x64\x65\x66\x61ult_documents\x18\x0e \x03(\t\x12&\n\x1e\x64\x65tailed_error_logging_enabled\x18\x0f \x01(\x08\x12\x15\n\rdocument_root\x18\x10 \x01(\t\x12\x41\n\x0b\x65xperiments\x18\x11 \x01(\x0b\x32,.oak9.tython.azure.microsoft_web.Experiments\x12\x12\n\nftps_state\x18\x12 \x01(\t\x12 \n\x18\x66unction_app_scale_limit\x18\x13 \x01(\x05\x12\x32\n*functions_runtime_scale_monitoring_enabled\x18\x14 \x01(\x08\x12I\n\x10handler_mappings\x18\x15 \x03(\x0b\x32/.oak9.tython.azure.microsoft_web.HandlerMapping\x12\x19\n\x11health_check_path\x18\x16 \x01(\t\x12\x16\n\x0ehttp20_enabled\x18\x17 \x01(\x08\x12\x1c\n\x14http_logging_enabled\x18\x18 \x01(\x08\x12X\n\x18ip_security_restrictions\x18\x19 \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_web.IpSecurityRestriction\x12\x16\n\x0ejava_container\x18\x1a \x01(\t\x12\x1e\n\x16java_container_version\x18\x1b \x01(\t\x12\x14\n\x0cjava_version\x18\x1c \x01(\t\x12$\n\x1ckey_vault_reference_identity\x18\x1d \x01(\t\x12;\n\x06limits\x18\x1e \x01(\x0b\x32+.oak9.tython.azure.microsoft_web.SiteLimits\x12\x18\n\x10linux_fx_version\x18\x1f \x01(\t\x12\x16\n\x0eload_balancing\x18  \x01(\t\x12\x1c\n\x14local_my_sql_enabled\x18! \x01(\x08\x12!\n\x19logs_directory_size_limit\x18\" \x01(\x05\x12\x1d\n\x15managed_pipeline_mode\x18# \x01(\t\x12#\n\x1bmanaged_service_identity_id\x18$ \x01(\x05\x12&\n\x1eminimum_elastic_instance_count\x18% \x01(\x05\x12\x17\n\x0fmin_tls_version\x18& \x01(\t\x12\x1d\n\x15net_framework_version\x18\' \x01(\t\x12\x14\n\x0cnode_version\x18( \x01(\t\x12\x19\n\x11number_of_workers\x18) \x01(\x05\x12\x13\n\x0bphp_version\x18* \x01(\t\x12\x1b\n\x13power_shell_version\x18+ \x01(\t\x12!\n\x19pre_warmed_instance_count\x18, \x01(\x05\x12\x1d\n\x15public_network_access\x18- \x01(\t\x12\x1b\n\x13publishing_username\x18. \x01(\t\x12;\n\x04push\x18/ \x01(\x0b\x32-.oak9.tython.azure.microsoft_web.PushSettings\x12\x16\n\x0epython_version\x18\x30 \x01(\t\x12 \n\x18remote_debugging_enabled\x18\x31 \x01(\x08\x12 \n\x18remote_debugging_version\x18\x32 \x01(\t\x12\x1f\n\x17request_tracing_enabled\x18\x33 \x01(\x08\x12\'\n\x1frequest_tracing_expiration_time\x18\x34 \x01(\t\x12\\\n\x1cscm_ip_security_restrictions\x18\x35 \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_web.IpSecurityRestriction\x12-\n%scm_ip_security_restrictions_use_main\x18\x36 \x01(\x08\x12\x1b\n\x13scm_min_tls_version\x18\x37 \x01(\t\x12\x10\n\x08scm_type\x18\x38 \x01(\t\x12\x17\n\x0ftracing_options\x18\x39 \x01(\t\x12 \n\x18use32_bit_worker_process\x18: \x01(\x08\x12Q\n\x14virtual_applications\x18; \x03(\x0b\x32\x33.oak9.tython.azure.microsoft_web.VirtualApplication\x12\x11\n\tvnet_name\x18< \x01(\t\x12 \n\x18vnet_private_ports_count\x18= \x01(\x05\x12\x1e\n\x16vnet_route_all_enabled\x18> \x01(\x08\x12\x19\n\x11website_time_zone\x18? \x01(\t\x12\x1b\n\x13web_sockets_enabled\x18@ \x01(\x08\x12\x1a\n\x12windows_fx_version\x18\x41 \x01(\t\x12%\n\x1dx_managed_service_identity_id\x18\x42 \x01(\x05\x1a;\n\x19\x41zureStorageAccountsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xaa\x01\n\x12VirtualApplication\x12\x15\n\rphysical_path\x18\x01 \x01(\t\x12\x17\n\x0fpreload_enabled\x18\x02 \x01(\x08\x12N\n\x13virtual_directories\x18\x03 \x03(\x0b\x32\x31.oak9.tython.azure.microsoft_web.VirtualDirectory\x12\x14\n\x0cvirtual_path\x18\x04 \x01(\t\"?\n\x10VirtualDirectory\x12\x15\n\rphysical_path\x18\x01 \x01(\t\x12\x14\n\x0cvirtual_path\x18\x02 \x01(\t\"\x89\x01\n\x0cPushSettings\x12\x0c\n\x04kind\x18\x01 \x01(\t\x12\x19\n\x11\x64ynamic_tags_json\x18\x02 \x01(\t\x12\x17\n\x0fis_push_enabled\x18\x03 \x01(\x08\x12\x1b\n\x13tags_requiring_auth\x18\x04 \x01(\t\x12\x1a\n\x12tag_whitelist_json\x18\x05 \x01(\t\"_\n\nSiteLimits\x12\x1b\n\x13max_disk_size_in_mb\x18\x01 \x01(\x05\x12\x18\n\x10max_memory_in_mb\x18\x02 \x01(\x05\x12\x1a\n\x12max_percentage_cpu\x18\x03 \x01(\x01\"\xef\x02\n\x15IpSecurityRestriction\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12T\n\x07headers\x18\x03 \x03(\x0b\x32\x43.oak9.tython.azure.microsoft_web.IpSecurityRestriction.HeadersEntry\x12\x12\n\nip_address\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x10\n\x08priority\x18\x06 \x01(\x05\x12\x13\n\x0bsubnet_mask\x18\x07 \x01(\t\x12\x1a\n\x12subnet_traffic_tag\x18\x08 \x01(\x05\x12\x0b\n\x03tag\x18\t \x01(\t\x12\x1f\n\x17vnet_subnet_resource_id\x18\n \x01(\t\x12\x18\n\x10vnet_traffic_tag\x18\x0b \x01(\x05\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"P\n\x0eHandlerMapping\x12\x11\n\targuments\x18\x01 \x01(\t\x12\x11\n\textension\x18\x02 \x01(\t\x12\x18\n\x10script_processor\x18\x03 \x01(\t\"Q\n\x0b\x45xperiments\x12\x42\n\rramp_up_rules\x18\x01 \x03(\x0b\x32+.oak9.tython.azure.microsoft_web.RampUpRule\"\xef\x01\n\nRampUpRule\x12\x18\n\x10\x61\x63tion_host_name\x18\x01 \x01(\t\x12$\n\x1c\x63hange_decision_callback_url\x18\x02 \x01(\t\x12\"\n\x1a\x63hange_interval_in_minutes\x18\x03 \x01(\x05\x12\x13\n\x0b\x63hange_step\x18\x04 \x01(\x01\x12\x1e\n\x16max_reroute_percentage\x18\x05 \x01(\x01\x12\x1e\n\x16min_reroute_percentage\x18\x06 \x01(\x01\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x1a\n\x12reroute_percentage\x18\x08 \x01(\x01\"D\n\x0c\x43orsSettings\x12\x17\n\x0f\x61llowed_origins\x18\x01 \x03(\t\x12\x1b\n\x13support_credentials\x18\x02 \x01(\x08\"G\n\x0e\x43onnStringInfo\x12\x19\n\x11\x63onnection_string\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\"\x97\x01\n\rAutoHealRules\x12\x41\n\x07\x61\x63tions\x18\x01 \x01(\x0b\x32\x30.oak9.tython.azure.microsoft_web.AutoHealActions\x12\x43\n\x08triggers\x18\x02 \x01(\x0b\x32\x31.oak9.tython.azure.microsoft_web.AutoHealTriggers\"\xd1\x03\n\x10\x41utoHealTriggers\x12\x1b\n\x13private_bytes_in_kb\x18\x01 \x01(\x05\x12G\n\x08requests\x18\x02 \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_web.RequestsBasedTrigger\x12P\n\rslow_requests\x18\x03 \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_web.SlowRequestsBasedTrigger\x12Z\n\x17slow_requests_with_path\x18\x04 \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_web.SlowRequestsBasedTrigger\x12N\n\x0cstatus_codes\x18\x05 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_web.StatusCodesBasedTrigger\x12Y\n\x12status_codes_range\x18\x06 \x03(\x0b\x32=.oak9.tython.azure.microsoft_web.StatusCodesRangeBasedTrigger\"h\n\x1cStatusCodesRangeBasedTrigger\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x14\n\x0cstatus_codes\x18\x03 \x01(\t\x12\x15\n\rtime_interval\x18\x04 \x01(\t\"\x87\x01\n\x17StatusCodesBasedTrigger\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\x05\x12\x12\n\nsub_status\x18\x04 \x01(\x05\x12\x15\n\rtime_interval\x18\x05 \x01(\t\x12\x14\n\x0cwin32_status\x18\x06 \x01(\x05\"b\n\x18SlowRequestsBasedTrigger\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x15\n\rtime_interval\x18\x03 \x01(\t\x12\x12\n\ntime_taken\x18\x04 \x01(\t\"<\n\x14RequestsBasedTrigger\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\x12\x15\n\rtime_interval\x18\x02 \x01(\t\"\x98\x01\n\x0f\x41utoHealActions\x12\x13\n\x0b\x61\x63tion_type\x18\x01 \x01(\t\x12L\n\rcustom_action\x18\x02 \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_web.AutoHealCustomAction\x12\"\n\x1amin_process_execution_time\x18\x03 \x01(\t\"7\n\x14\x41utoHealCustomAction\x12\x0b\n\x03\x65xe\x18\x01 \x01(\t\x12\x12\n\nparameters\x18\x02 \x01(\t\"!\n\x13\x41piManagementConfig\x12\n\n\x02id\x18\x01 \x01(\t\" \n\x11\x41piDefinitionInfo\x12\x0b\n\x03url\x18\x01 \x01(\t\"\x81\x01\n\x10HostNameSslState\x12\x11\n\thost_type\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tssl_state\x18\x03 \x01(\t\x12\x12\n\nthumbprint\x18\x04 \x01(\t\x12\x11\n\tto_update\x18\x05 \x01(\x08\x12\x12\n\nvirtual_ip\x18\x06 \x01(\t\"\xe1\x03\n\x0b\x43loningInfo\x12\x66\n\x16\x61pp_settings_overrides\x18\x01 \x03(\x0b\x32\x46.oak9.tython.azure.microsoft_web.CloningInfo.AppSettingsOverridesEntry\x12\x1f\n\x17\x63lone_custom_host_names\x18\x02 \x01(\x08\x12\x1c\n\x14\x63lone_source_control\x18\x03 \x01(\x08\x12 \n\x18\x63onfigure_load_balancing\x18\x04 \x01(\x08\x12\x16\n\x0e\x63orrelation_id\x18\x05 \x01(\t\x12\x1b\n\x13hosting_environment\x18\x06 \x01(\t\x12\x11\n\toverwrite\x18\x07 \x01(\x08\x12\x19\n\x11source_web_app_id\x18\x08 \x01(\t\x12\x1f\n\x17source_web_app_location\x18\t \x01(\t\x12\"\n\x1atraffic_manager_profile_id\x18\n \x01(\t\x12$\n\x1ctraffic_manager_profile_name\x18\x0b \x01(\t\x1a;\n\x19\x41ppSettingsOverridesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xdc\x01\n\x16ManagedServiceIdentity\x12\x0c\n\x04type\x18\x01 \x01(\t\x12u\n\x18user_assigned_identities\x18\x02 \x03(\x0b\x32S.oak9.tython.azure.microsoft_web.ManagedServiceIdentity.UserAssignedIdentitiesEntry\x1a=\n\x1bUserAssignedIdentitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc1\x01\n*ServerfarmsVirtualNetworkConnectionsRoutes\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x65nd_address\x18\x04 \x01(\t\x12\x12\n\nroute_type\x18\x05 \x01(\t\x12\x15\n\rstart_address\x18\x06 \x01(\t\"\xaf\x01\n,ServerfarmsVirtualNetworkConnectionsGateways\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tvnet_name\x18\x04 \x01(\t\x12\x17\n\x0fvpn_package_uri\x18\x05 \x01(\t\"\x84\x07\n\x0bServerfarms\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12L\n\x11\x65xtended_location\x18\x02 \x01(\x0b\x32\x31.oak9.tython.azure.microsoft_web.ExtendedLocation\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x1d\n\x15\x65lastic_scale_enabled\x18\x06 \x01(\x08\x12\"\n\x1a\x66ree_offer_expiration_time\x18\x07 \x01(\t\x12_\n\x1bhosting_environment_profile\x18\x08 \x01(\x0b\x32:.oak9.tython.azure.microsoft_web.HostingEnvironmentProfile\x12\x0f\n\x07hyper_v\x18\t \x01(\x08\x12\x0f\n\x07is_spot\x18\n \x01(\x08\x12\x10\n\x08is_xenon\x18\x0b \x01(\x08\x12Y\n\x18kube_environment_profile\x18\x0c \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_web.KubeEnvironmentProfile\x12$\n\x1cmaximum_elastic_worker_count\x18\r \x01(\x05\x12\x18\n\x10per_site_scaling\x18\x0e \x01(\x08\x12\x10\n\x08reserved\x18\x0f \x01(\x08\x12\x1c\n\x14spot_expiration_time\x18\x10 \x01(\t\x12\x1b\n\x13target_worker_count\x18\x11 \x01(\x05\x12\x1d\n\x15target_worker_size_id\x18\x12 \x01(\x05\x12\x18\n\x10worker_tier_name\x18\x13 \x01(\t\x12\x16\n\x0ezone_redundant\x18\x14 \x01(\x08\x12<\n\x03sku\x18\x15 \x01(\x0b\x32/.oak9.tython.azure.microsoft_web.SkuDescription\x12\x44\n\x04tags\x18\x16 \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_web.Serverfarms.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"$\n\x16KubeEnvironmentProfile\x12\n\n\x02id\x18\x01 \x01(\t\"\'\n\x19HostingEnvironmentProfile\x12\n\n\x02id\x18\x01 \x01(\t\"\xb5\x05\n\x10KubeEnvironments\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12L\n\x11\x65xtended_location\x18\x02 \x01(\x0b\x32\x31.oak9.tython.azure.microsoft_web.ExtendedLocation\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x17\n\x0f\x61ks_resource_id\x18\x06 \x01(\t\x12U\n\x16\x61pp_logs_configuration\x18\x07 \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_web.AppLogsConfiguration\x12L\n\x11\x61rc_configuration\x18\x08 \x01(\x0b\x32\x31.oak9.tython.azure.microsoft_web.ArcConfiguration\x12\x61\n\x1c\x63ontainer_apps_configuration\x18\t \x01(\x0b\x32;.oak9.tython.azure.microsoft_web.ContainerAppsConfiguration\x12\x18\n\x10\x65nvironment_type\x18\n \x01(\t\x12&\n\x1einternal_load_balancer_enabled\x18\x0b \x01(\x08\x12\x11\n\tstatic_ip\x18\x0c \x01(\t\x12I\n\x04tags\x18\r \x03(\x0b\x32;.oak9.tython.azure.microsoft_web.KubeEnvironments.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xea\x01\n\x1a\x43ontainerAppsConfiguration\x12\x1e\n\x16\x61pp_subnet_resource_id\x18\x01 \x01(\t\x12(\n control_plane_subnet_resource_id\x18\x02 \x01(\t\x12$\n\x1c\x64\x61pr_a_i_instrumentation_key\x18\x03 \x01(\t\x12\x1a\n\x12\x64ocker_bridge_cidr\x18\x04 \x01(\t\x12\x1e\n\x16platform_reserved_cidr\x18\x05 \x01(\t\x12 \n\x18platform_reserved_dns_ip\x18\x06 \x01(\t\"\xbc\x02\n\x10\x41rcConfiguration\x12\x1e\n\x16\x61rtifacts_storage_type\x18\x01 \x01(\t\x12$\n\x1c\x61rtifact_storage_access_mode\x18\x02 \x01(\t\x12#\n\x1b\x61rtifact_storage_class_name\x18\x03 \x01(\t\x12#\n\x1b\x61rtifact_storage_mount_path\x18\x04 \x01(\t\x12\"\n\x1a\x61rtifact_storage_node_name\x18\x05 \x01(\t\x12_\n\x1f\x66ront_end_service_configuration\x18\x06 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_web.FrontEndConfiguration\x12\x13\n\x0bkube_config\x18\x07 \x01(\t\"%\n\x15\x46rontEndConfiguration\x12\x0c\n\x04kind\x18\x01 \x01(\t\"\x8c\x01\n\x14\x41ppLogsConfiguration\x12\x13\n\x0b\x64\x65stination\x18\x01 \x01(\t\x12_\n\x1blog_analytics_configuration\x18\x02 \x01(\x0b\x32:.oak9.tython.azure.microsoft_web.LogAnalyticsConfiguration\"D\n\x19LogAnalyticsConfiguration\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12\x12\n\nshared_key\x18\x02 \x01(\t\" \n\x10\x45xtendedLocation\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x8c\x02\n\x1eHostingEnvironmentsWorkerPools\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x14\n\x0c\x63ompute_mode\x18\x04 \x01(\t\x12\x14\n\x0cworker_count\x18\x05 \x01(\x05\x12\x13\n\x0bworker_size\x18\x06 \x01(\t\x12\x16\n\x0eworker_size_id\x18\x07 \x01(\x05\x12<\n\x03sku\x18\x08 \x01(\x0b\x32/.oak9.tython.azure.microsoft_web.SkuDescription\"\xf0\x01\n-HostingEnvironmentsPrivateEndpointConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12j\n%private_link_service_connection_state\x18\x04 \x01(\x0b\x32;.oak9.tython.azure.microsoft_web.PrivateLinkConnectionState\"[\n\x1aPrivateLinkConnectionState\x12\x18\n\x10\x61\x63tions_required\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\"\x8f\x02\n!HostingEnvironmentsMultiRolePools\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x14\n\x0c\x63ompute_mode\x18\x04 \x01(\t\x12\x14\n\x0cworker_count\x18\x05 \x01(\x05\x12\x13\n\x0bworker_size\x18\x06 \x01(\t\x12\x16\n\x0eworker_size_id\x18\x07 \x01(\x05\x12<\n\x03sku\x18\x08 \x01(\x0b\x32/.oak9.tython.azure.microsoft_web.SkuDescription\"\xf6\x01\n\x0eSkuDescription\x12\x41\n\x0c\x63\x61pabilities\x18\x01 \x03(\x0b\x32+.oak9.tython.azure.microsoft_web.Capability\x12\x10\n\x08\x63\x61pacity\x18\x02 \x01(\x05\x12\x0e\n\x06\x66\x61mily\x18\x03 \x01(\t\x12\x11\n\tlocations\x18\x04 \x03(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0c\n\x04size\x18\x06 \x01(\t\x12\x42\n\x0csku_capacity\x18\x07 \x01(\x0b\x32,.oak9.tython.azure.microsoft_web.SkuCapacity\x12\x0c\n\x04tier\x18\x08 \x01(\t\"m\n\x0bSkuCapacity\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x01 \x01(\x05\x12\x17\n\x0f\x65lastic_maximum\x18\x02 \x01(\x05\x12\x0f\n\x07maximum\x18\x03 \x01(\x05\x12\x0f\n\x07minimum\x18\x04 \x01(\x05\x12\x12\n\nscale_type\x18\x05 \x01(\t\"9\n\nCapability\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\\\n!HostingEnvironmentsConfigurations\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb8\n\n\x13HostingEnvironments\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12H\n\x10\x63luster_settings\x18\x05 \x03(\x0b\x32..oak9.tython.azure.microsoft_web.NameValuePair\x12\x66\n\x1f\x63ustom_dns_suffix_configuration\x18\x06 \x01(\x0b\x32=.oak9.tython.azure.microsoft_web.CustomDnsSuffixConfiguration\x12\x1c\n\x14\x64\x65\x64icated_host_count\x18\x07 \x01(\x05\x12\x12\n\ndns_suffix\x18\x08 \x01(\t\x12\x1e\n\x16\x66ront_end_scale_factor\x18\t \x01(\x05\x12$\n\x1cinternal_load_balancing_mode\x18\n \x01(\t\x12\x1b\n\x13ipssl_address_count\x18\x0b \x01(\x05\x12\x12\n\nmulti_size\x18\x0c \x01(\t\x12_\n\x18networking_configuration\x18\r \x01(\x0b\x32=.oak9.tython.azure.microsoft_web.AseV3NetworkingConfiguration\x12\x1a\n\x12upgrade_preference\x18\x0e \x01(\t\x12\"\n\x1auser_whitelisted_ip_ranges\x18\x0f \x03(\t\x12O\n\x0fvirtual_network\x18\x10 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_web.VirtualNetworkProfile\x12\x16\n\x0ezone_redundant\x18\x11 \x01(\x08\x12L\n\x04tags\x18\x12 \x03(\x0b\x32>.oak9.tython.azure.microsoft_web.HostingEnvironments.TagsEntry\x12o\n#hosting_environments_configurations\x18\x13 \x03(\x0b\x32\x42.oak9.tython.azure.microsoft_web.HostingEnvironmentsConfigurations\x12q\n%hosting_environments_multi_role_pools\x18\x14 \x03(\x0b\x32\x42.oak9.tython.azure.microsoft_web.HostingEnvironmentsMultiRolePools\x12\x89\x01\n1hosting_environments_private_endpoint_connections\x18\x15 \x03(\x0b\x32N.oak9.tython.azure.microsoft_web.HostingEnvironmentsPrivateEndpointConnections\x12j\n!hosting_environments_worker_pools\x18\x16 \x03(\x0b\x32?.oak9.tython.azure.microsoft_web.HostingEnvironmentsWorkerPools\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"3\n\x15VirtualNetworkProfile\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06subnet\x18\x02 \x01(\t\"\xb4\x01\n\x1c\x41seV3NetworkingConfiguration\x12\x0c\n\x04kind\x18\x01 \x01(\t\x12.\n&allow_new_private_endpoint_connections\x18\x02 \x01(\x08\x12\x13\n\x0b\x66tp_enabled\x18\x03 \x01(\x08\x12#\n\x1binbound_ip_address_override\x18\x04 \x01(\t\x12\x1c\n\x14remote_debug_enabled\x18\x05 \x01(\x08\"\x7f\n\x1c\x43ustomDnsSuffixConfiguration\x12\x0c\n\x04kind\x18\x01 \x01(\t\x12\x17\n\x0f\x63\x65rtificate_url\x18\x02 \x01(\t\x12\x12\n\ndns_suffix\x18\x03 \x01(\t\x12$\n\x1ckey_vault_reference_identity\x18\x04 \x01(\t\",\n\rNameValuePair\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x8c\x03\n\rContainerApps\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x45\n\rconfiguration\x18\x05 \x01(\x0b\x32..oak9.tython.azure.microsoft_web.Configuration\x12\x1b\n\x13kube_environment_id\x18\x06 \x01(\t\x12;\n\x08template\x18\x07 \x01(\x0b\x32).oak9.tython.azure.microsoft_web.Template\x12\x46\n\x04tags\x18\x08 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_web.ContainerApps.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xcf\x01\n\x08Template\x12>\n\ncontainers\x18\x01 \x03(\x0b\x32*.oak9.tython.azure.microsoft_web.Container\x12\x33\n\x04\x64\x61pr\x18\x02 \x01(\x0b\x32%.oak9.tython.azure.microsoft_web.Dapr\x12\x17\n\x0frevision_suffix\x18\x03 \x01(\t\x12\x35\n\x05scale\x18\x04 \x01(\x0b\x32&.oak9.tython.azure.microsoft_web.Scale\"n\n\x05Scale\x12\x14\n\x0cmax_replicas\x18\x01 \x01(\x05\x12\x14\n\x0cmin_replicas\x18\x02 \x01(\x05\x12\x39\n\x05rules\x18\x03 \x03(\x0b\x32*.oak9.tython.azure.microsoft_web.ScaleRule\"\xdf\x01\n\tScaleRule\x12\x44\n\x0b\x61zure_queue\x18\x01 \x01(\x0b\x32/.oak9.tython.azure.microsoft_web.QueueScaleRule\x12@\n\x06\x63ustom\x18\x02 \x01(\x0b\x32\x30.oak9.tython.azure.microsoft_web.CustomScaleRule\x12<\n\x04http\x18\x03 \x01(\x0b\x32..oak9.tython.azure.microsoft_web.HttpScaleRule\x12\x0c\n\x04name\x18\x04 \x01(\t\"\xce\x01\n\rHttpScaleRule\x12<\n\x04\x61uth\x18\x01 \x03(\x0b\x32..oak9.tython.azure.microsoft_web.ScaleRuleAuth\x12N\n\x08metadata\x18\x02 \x03(\x0b\x32<.oak9.tython.azure.microsoft_web.HttpScaleRule.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe0\x01\n\x0f\x43ustomScaleRule\x12<\n\x04\x61uth\x18\x01 \x03(\x0b\x32..oak9.tython.azure.microsoft_web.ScaleRuleAuth\x12P\n\x08metadata\x18\x02 \x03(\x0b\x32>.oak9.tython.azure.microsoft_web.CustomScaleRule.MetadataEntry\x12\x0c\n\x04type\x18\x03 \x01(\t\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"x\n\x0eQueueScaleRule\x12<\n\x04\x61uth\x18\x01 \x03(\x0b\x32..oak9.tython.azure.microsoft_web.ScaleRuleAuth\x12\x14\n\x0cqueue_length\x18\x02 \x01(\x05\x12\x12\n\nqueue_name\x18\x03 \x01(\t\">\n\rScaleRuleAuth\x12\x12\n\nsecret_ref\x18\x01 \x01(\t\x12\x19\n\x11trigger_parameter\x18\x02 \x01(\t\"}\n\x04\x44\x61pr\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\x12\x10\n\x08\x61pp_port\x18\x02 \x01(\x05\x12\x42\n\ncomponents\x18\x03 \x03(\x0b\x32..oak9.tython.azure.microsoft_web.DaprComponent\x12\x0f\n\x07\x65nabled\x18\x04 \x01(\x08\"}\n\rDaprComponent\x12?\n\x08metadata\x18\x01 \x03(\x0b\x32-.oak9.tython.azure.microsoft_web.DaprMetadata\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\"?\n\x0c\x44\x61prMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nsecret_ref\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\x85\x01\n\tContainer\x12\x0c\n\x04\x61rgs\x18\x01 \x03(\t\x12\x0f\n\x07\x63ommand\x18\x02 \x03(\t\x12<\n\x03\x65nv\x18\x03 \x03(\x0b\x32/.oak9.tython.azure.microsoft_web.EnvironmentVar\x12\r\n\x05image\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\"A\n\x0e\x45nvironmentVar\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nsecret_ref\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xed\x01\n\rConfiguration\x12\x1d\n\x15\x61\x63tive_revisions_mode\x18\x01 \x01(\t\x12\x39\n\x07ingress\x18\x02 \x01(\x0b\x32(.oak9.tython.azure.microsoft_web.Ingress\x12H\n\nregistries\x18\x03 \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_web.RegistryCredentials\x12\x38\n\x07secrets\x18\x04 \x03(\x0b\x32\'.oak9.tython.azure.microsoft_web.Secret\"%\n\x06Secret\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"T\n\x13RegistryCredentials\x12\x1b\n\x13password_secret_ref\x18\x01 \x01(\t\x12\x0e\n\x06server\x18\x02 \x01(\t\x12\x10\n\x08username\x18\x03 \x01(\t\"\x9c\x01\n\x07Ingress\x12\x16\n\x0e\x61llow_insecure\x18\x01 \x01(\x08\x12\x10\n\x08\x65xternal\x18\x02 \x01(\x08\x12\x13\n\x0btarget_port\x18\x03 \x01(\x05\x12?\n\x07traffic\x18\x04 \x03(\x0b\x32..oak9.tython.azure.microsoft_web.TrafficWeight\x12\x11\n\ttransport\x18\x05 \x01(\t\"O\n\rTrafficWeight\x12\x17\n\x0flatest_revision\x18\x01 \x01(\x08\x12\x15\n\rrevision_name\x18\x02 \x01(\t\x12\x0e\n\x06weight\x18\x03 \x01(\x05\"\xa8\x03\n\x0c\x43\x65rtificates\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x16\n\x0e\x63\x61nonical_name\x18\x05 \x01(\t\x12 \n\x18\x64omain_validation_method\x18\x06 \x01(\t\x12\x12\n\nhost_names\x18\x07 \x03(\t\x12\x14\n\x0ckey_vault_id\x18\x08 \x01(\t\x12\x1d\n\x15key_vault_secret_name\x18\t \x01(\t\x12\x10\n\x08password\x18\n \x01(\t\x12\x10\n\x08pfx_blob\x18\x0b \x01(\t\x12\x16\n\x0eserver_farm_id\x18\x0c \x01(\t\x12\x45\n\x04tags\x18\r \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_web.Certificates.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_web_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STATICSITES_TAGSENTRY._options = None
  _STATICSITES_TAGSENTRY._serialized_options = b'8\001'
  _SITESSLOTSPREMIERADDONS_TAGSENTRY._options = None
  _SITESSLOTSPREMIERADDONS_TAGSENTRY._serialized_options = b'8\001'
  _SITESSLOTSINSTANCESEXTENSIONS_SETPARAMETERSENTRY._options = None
  _SITESSLOTSINSTANCESEXTENSIONS_SETPARAMETERSENTRY._serialized_options = b'8\001'
  _SITESSLOTSFUNCTIONS_CONFIGENTRY._options = None
  _SITESSLOTSFUNCTIONS_CONFIGENTRY._serialized_options = b'8\001'
  _SITESSLOTSFUNCTIONS_FILESENTRY._options = None
  _SITESSLOTSFUNCTIONS_FILESENTRY._serialized_options = b'8\001'
  _SITESSLOTSEXTENSIONS_SETPARAMETERSENTRY._options = None
  _SITESSLOTSEXTENSIONS_SETPARAMETERSENTRY._serialized_options = b'8\001'
  _SITESSLOTS_TAGSENTRY._options = None
  _SITESSLOTS_TAGSENTRY._serialized_options = b'8\001'
  _SITESPREMIERADDONS_TAGSENTRY._options = None
  _SITESPREMIERADDONS_TAGSENTRY._serialized_options = b'8\001'
  _SITESINSTANCESEXTENSIONS_SETPARAMETERSENTRY._options = None
  _SITESINSTANCESEXTENSIONS_SETPARAMETERSENTRY._serialized_options = b'8\001'
  _SITESFUNCTIONS_CONFIGENTRY._options = None
  _SITESFUNCTIONS_CONFIGENTRY._serialized_options = b'8\001'
  _SITESFUNCTIONS_FILESENTRY._options = None
  _SITESFUNCTIONS_FILESENTRY._serialized_options = b'8\001'
  _SITES_TAGSENTRY._options = None
  _SITES_TAGSENTRY._serialized_options = b'8\001'
  _SITECONFIG_AZURESTORAGEACCOUNTSENTRY._options = None
  _SITECONFIG_AZURESTORAGEACCOUNTSENTRY._serialized_options = b'8\001'
  _IPSECURITYRESTRICTION_HEADERSENTRY._options = None
  _IPSECURITYRESTRICTION_HEADERSENTRY._serialized_options = b'8\001'
  _CLONINGINFO_APPSETTINGSOVERRIDESENTRY._options = None
  _CLONINGINFO_APPSETTINGSOVERRIDESENTRY._serialized_options = b'8\001'
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._options = None
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_options = b'8\001'
  _SERVERFARMS_TAGSENTRY._options = None
  _SERVERFARMS_TAGSENTRY._serialized_options = b'8\001'
  _KUBEENVIRONMENTS_TAGSENTRY._options = None
  _KUBEENVIRONMENTS_TAGSENTRY._serialized_options = b'8\001'
  _HOSTINGENVIRONMENTS_TAGSENTRY._options = None
  _HOSTINGENVIRONMENTS_TAGSENTRY._serialized_options = b'8\001'
  _CONTAINERAPPS_TAGSENTRY._options = None
  _CONTAINERAPPS_TAGSENTRY._serialized_options = b'8\001'
  _HTTPSCALERULE_METADATAENTRY._options = None
  _HTTPSCALERULE_METADATAENTRY._serialized_options = b'8\001'
  _CUSTOMSCALERULE_METADATAENTRY._options = None
  _CUSTOMSCALERULE_METADATAENTRY._serialized_options = b'8\001'
  _CERTIFICATES_TAGSENTRY._options = None
  _CERTIFICATES_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_WEB._serialized_start=90
  _MICROSOFT_WEB._serialized_end=818
  _STATICSITESUSERPROVIDEDFUNCTIONAPPS._serialized_start=821
  _STATICSITESUSERPROVIDEDFUNCTIONAPPS._serialized_end=1006
  _STATICSITESPRIVATEENDPOINTCONNECTIONS._serialized_start=1009
  _STATICSITESPRIVATEENDPOINTCONNECTIONS._serialized_end=1241
  _STATICSITESLINKEDBACKENDS._serialized_start=1244
  _STATICSITESLINKEDBACKENDS._serialized_end=1401
  _STATICSITESCUSTOMDOMAINS._serialized_start=1404
  _STATICSITESCUSTOMDOMAINS._serialized_end=1542
  _STATICSITESCONFIG._serialized_start=1544
  _STATICSITESCONFIG._serialized_end=1620
  _STATICSITESBUILDSUSERPROVIDEDFUNCTIONAPPS._serialized_start=1623
  _STATICSITESBUILDSUSERPROVIDEDFUNCTIONAPPS._serialized_end=1814
  _STATICSITESBUILDSLINKEDBACKENDS._serialized_start=1817
  _STATICSITESBUILDSLINKEDBACKENDS._serialized_end=1980
  _STATICSITESBUILDSCONFIG._serialized_start=1982
  _STATICSITESBUILDSCONFIG._serialized_end=2064
  _STATICSITES._serialized_start=2067
  _STATICSITES._serialized_end=3351
  _STATICSITES_TAGSENTRY._serialized_start=3308
  _STATICSITES_TAGSENTRY._serialized_end=3351
  _STATICSITETEMPLATEOPTIONS._serialized_start=3354
  _STATICSITETEMPLATEOPTIONS._serialized_end=3495
  _STATICSITEBUILDPROPERTIES._serialized_start=3498
  _STATICSITEBUILDPROPERTIES._serialized_end=3771
  _SITESVIRTUALNETWORKCONNECTIONSGATEWAYS._serialized_start=3774
  _SITESVIRTUALNETWORKCONNECTIONSGATEWAYS._serialized_end=3943
  _SITESVIRTUALNETWORKCONNECTIONS._serialized_start=3946
  _SITESVIRTUALNETWORKCONNECTIONS._serialized_end=4272
  _SITESSOURCECONTROLS._serialized_start=4275
  _SITESSOURCECONTROLS._serialized_end=4630
  _SITESSLOTSVIRTUALNETWORKCONNECTIONSGATEWAYS._serialized_start=4633
  _SITESSLOTSVIRTUALNETWORKCONNECTIONSGATEWAYS._serialized_end=4807
  _SITESSLOTSVIRTUALNETWORKCONNECTIONS._serialized_start=4810
  _SITESSLOTSVIRTUALNETWORKCONNECTIONS._serialized_end=5153
  _SITESSLOTSSOURCECONTROLS._serialized_start=5156
  _SITESSLOTSSOURCECONTROLS._serialized_end=5516
  _GITHUBACTIONCONFIGURATION._serialized_start=5519
  _GITHUBACTIONCONFIGURATION._serialized_end=5790
  _GITHUBACTIONCONTAINERCONFIGURATION._serialized_start=5792
  _GITHUBACTIONCONTAINERCONFIGURATION._serialized_end=5904
  _GITHUBACTIONCODECONFIGURATION._serialized_start=5906
  _GITHUBACTIONCODECONFIGURATION._serialized_end=5985
  _SITESSLOTSSITEEXTENSIONS._serialized_start=5987
  _SITESSLOTSSITEEXTENSIONS._serialized_end=6084
  _SITESSLOTSPUBLICCERTIFICATES._serialized_start=6087
  _SITESSLOTSPUBLICCERTIFICATES._serialized_end=6253
  _SITESSLOTSPRIVATEENDPOINTCONNECTIONS._serialized_start=6256
  _SITESSLOTSPRIVATEENDPOINTCONNECTIONS._serialized_end=6487
  _SITESSLOTSPRIVATEACCESS._serialized_start=6490
  _SITESSLOTSPRIVATEACCESS._serialized_end=6705
  _SITESSLOTSPREMIERADDONS._serialized_start=6708
  _SITESSLOTSPREMIERADDONS._serialized_end=7067
  _SITESSLOTSPREMIERADDONS_TAGSENTRY._serialized_start=3308
  _SITESSLOTSPREMIERADDONS_TAGSENTRY._serialized_end=3351
  _SITESSLOTSNETWORKCONFIG._serialized_start=7070
  _SITESSLOTSNETWORKCONFIG._serialized_end=7233
  _SITESSLOTSINSTANCESEXTENSIONS._serialized_start=7236
  _SITESSLOTSINSTANCESEXTENSIONS._serialized_end=7659
  _SITESSLOTSINSTANCESEXTENSIONS_SETPARAMETERSENTRY._serialized_start=7607
  _SITESSLOTSINSTANCESEXTENSIONS_SETPARAMETERSENTRY._serialized_end=7659
  _SITESSLOTSHYBRIDCONNECTIONNAMESPACESRELAYS._serialized_start=7662
  _SITESSLOTSHYBRIDCONNECTIONNAMESPACESRELAYS._serialized_end=7972
  _SITESSLOTSHYBRIDCONNECTION._serialized_start=7975
  _SITESSLOTSHYBRIDCONNECTION._serialized_end=8255
  _SITESSLOTSHOSTNAMEBINDINGS._serialized_start=8258
  _SITESSLOTSHOSTNAMEBINDINGS._serialized_end=8572
  _SITESSLOTSFUNCTIONSKEYS._serialized_start=8574
  _SITESSLOTSFUNCTIONSKEYS._serialized_end=8685
  _SITESSLOTSFUNCTIONS._serialized_start=8688
  _SITESSLOTSFUNCTIONS._serialized_end=9393
  _SITESSLOTSFUNCTIONS_CONFIGENTRY._serialized_start=9302
  _SITESSLOTSFUNCTIONS_CONFIGENTRY._serialized_end=9347
  _SITESSLOTSFUNCTIONS_FILESENTRY._serialized_start=9349
  _SITESSLOTSFUNCTIONS_FILESENTRY._serialized_end=9393
  _SITESSLOTSEXTENSIONS._serialized_start=9396
  _SITESSLOTSEXTENSIONS._serialized_end=9801
  _SITESSLOTSEXTENSIONS_SETPARAMETERSENTRY._serialized_start=7607
  _SITESSLOTSEXTENSIONS_SETPARAMETERSENTRY._serialized_end=7659
  _SITESSLOTSDOMAINOWNERSHIPIDENTIFIERS._serialized_start=9804
  _SITESSLOTSDOMAINOWNERSHIPIDENTIFIERS._serialized_end=9939
  _SITESSLOTSDEPLOYMENTS._serialized_start=9942
  _SITESSLOTSDEPLOYMENTS._serialized_end=10210
  _SITESSLOTSCONFIG._serialized_start=10212
  _SITESSLOTSCONFIG._serialized_end=10287
  _SITESSLOTSBASICPUBLISHINGCREDENTIALSPOLICIES._serialized_start=10289
  _SITESSLOTSBASICPUBLISHINGCREDENTIALSPOLICIES._serialized_end=10392
  _SITESSLOTS._serialized_start=10395
  _SITESSLOTS._serialized_end=13363
  _SITESSLOTS_TAGSENTRY._serialized_start=3308
  _SITESSLOTS_TAGSENTRY._serialized_end=3351
  _SITESSITEEXTENSIONS._serialized_start=13365
  _SITESSITEEXTENSIONS._serialized_end=13457
  _SITESPUBLICCERTIFICATES._serialized_start=13460
  _SITESPUBLICCERTIFICATES._serialized_end=13621
  _SITESPRIVATEENDPOINTCONNECTIONS._serialized_start=13624
  _SITESPRIVATEENDPOINTCONNECTIONS._serialized_end=13850
  _SITESPRIVATEACCESS._serialized_start=13853
  _SITESPRIVATEACCESS._serialized_end=14063
  _PRIVATEACCESSVIRTUALNETWORK._serialized_start=14066
  _PRIVATEACCESSVIRTUALNETWORK._serialized_end=14214
  _PRIVATEACCESSSUBNET._serialized_start=14216
  _PRIVATEACCESSSUBNET._serialized_end=14264
  _SITESPREMIERADDONS._serialized_start=14267
  _SITESPREMIERADDONS._serialized_end=14616
  _SITESPREMIERADDONS_TAGSENTRY._serialized_start=3308
  _SITESPREMIERADDONS_TAGSENTRY._serialized_end=3351
  _SITESNETWORKCONFIG._serialized_start=14619
  _SITESNETWORKCONFIG._serialized_end=14777
  _SITESMIGRATE._serialized_start=14780
  _SITESMIGRATE._serialized_end=15016
  _SITESINSTANCESEXTENSIONS._serialized_start=15019
  _SITESINSTANCESEXTENSIONS._serialized_end=15432
  _SITESINSTANCESEXTENSIONS_SETPARAMETERSENTRY._serialized_start=7607
  _SITESINSTANCESEXTENSIONS_SETPARAMETERSENTRY._serialized_end=7659
  _SITESHYBRIDCONNECTIONNAMESPACESRELAYS._serialized_start=15435
  _SITESHYBRIDCONNECTIONNAMESPACESRELAYS._serialized_end=15740
  _SITESHYBRIDCONNECTION._serialized_start=15743
  _SITESHYBRIDCONNECTION._serialized_end=16018
  _SITESHOSTNAMEBINDINGS._serialized_start=16021
  _SITESHOSTNAMEBINDINGS._serialized_end=16330
  _SITESFUNCTIONSKEYS._serialized_start=16332
  _SITESFUNCTIONSKEYS._serialized_end=16438
  _SITESFUNCTIONS._serialized_start=16441
  _SITESFUNCTIONS._serialized_end=17120
  _SITESFUNCTIONS_CONFIGENTRY._serialized_start=9302
  _SITESFUNCTIONS_CONFIGENTRY._serialized_end=9347
  _SITESFUNCTIONS_FILESENTRY._serialized_start=9349
  _SITESFUNCTIONS_FILESENTRY._serialized_end=9393
  _SITESEXTENSIONS._serialized_start=17122
  _SITESEXTENSIONS._serialized_end=17196
  _SITESDOMAINOWNERSHIPIDENTIFIERS._serialized_start=17199
  _SITESDOMAINOWNERSHIPIDENTIFIERS._serialized_end=17329
  _SITESDEPLOYMENTS._serialized_start=17332
  _SITESDEPLOYMENTS._serialized_end=17595
  _SITESCONFIG._serialized_start=17598
  _SITESCONFIG._serialized_end=18258
  _SITESBASICPUBLISHINGCREDENTIALSPOLICIES._serialized_start=18260
  _SITESBASICPUBLISHINGCREDENTIALSPOLICIES._serialized_end=18358
  _SITES._serialized_start=18361
  _SITES._serialized_end=21042
  _SITES_TAGSENTRY._serialized_start=3308
  _SITES_TAGSENTRY._serialized_end=3351
  _SITECONFIG._serialized_start=21045
  _SITECONFIG._serialized_end=23766
  _SITECONFIG_AZURESTORAGEACCOUNTSENTRY._serialized_start=23707
  _SITECONFIG_AZURESTORAGEACCOUNTSENTRY._serialized_end=23766
  _VIRTUALAPPLICATION._serialized_start=23769
  _VIRTUALAPPLICATION._serialized_end=23939
  _VIRTUALDIRECTORY._serialized_start=23941
  _VIRTUALDIRECTORY._serialized_end=24004
  _PUSHSETTINGS._serialized_start=24007
  _PUSHSETTINGS._serialized_end=24144
  _SITELIMITS._serialized_start=24146
  _SITELIMITS._serialized_end=24241
  _IPSECURITYRESTRICTION._serialized_start=24244
  _IPSECURITYRESTRICTION._serialized_end=24611
  _IPSECURITYRESTRICTION_HEADERSENTRY._serialized_start=24565
  _IPSECURITYRESTRICTION_HEADERSENTRY._serialized_end=24611
  _HANDLERMAPPING._serialized_start=24613
  _HANDLERMAPPING._serialized_end=24693
  _EXPERIMENTS._serialized_start=24695
  _EXPERIMENTS._serialized_end=24776
  _RAMPUPRULE._serialized_start=24779
  _RAMPUPRULE._serialized_end=25018
  _CORSSETTINGS._serialized_start=25020
  _CORSSETTINGS._serialized_end=25088
  _CONNSTRINGINFO._serialized_start=25090
  _CONNSTRINGINFO._serialized_end=25161
  _AUTOHEALRULES._serialized_start=25164
  _AUTOHEALRULES._serialized_end=25315
  _AUTOHEALTRIGGERS._serialized_start=25318
  _AUTOHEALTRIGGERS._serialized_end=25783
  _STATUSCODESRANGEBASEDTRIGGER._serialized_start=25785
  _STATUSCODESRANGEBASEDTRIGGER._serialized_end=25889
  _STATUSCODESBASEDTRIGGER._serialized_start=25892
  _STATUSCODESBASEDTRIGGER._serialized_end=26027
  _SLOWREQUESTSBASEDTRIGGER._serialized_start=26029
  _SLOWREQUESTSBASEDTRIGGER._serialized_end=26127
  _REQUESTSBASEDTRIGGER._serialized_start=26129
  _REQUESTSBASEDTRIGGER._serialized_end=26189
  _AUTOHEALACTIONS._serialized_start=26192
  _AUTOHEALACTIONS._serialized_end=26344
  _AUTOHEALCUSTOMACTION._serialized_start=26346
  _AUTOHEALCUSTOMACTION._serialized_end=26401
  _APIMANAGEMENTCONFIG._serialized_start=26403
  _APIMANAGEMENTCONFIG._serialized_end=26436
  _APIDEFINITIONINFO._serialized_start=26438
  _APIDEFINITIONINFO._serialized_end=26470
  _HOSTNAMESSLSTATE._serialized_start=26473
  _HOSTNAMESSLSTATE._serialized_end=26602
  _CLONINGINFO._serialized_start=26605
  _CLONINGINFO._serialized_end=27086
  _CLONINGINFO_APPSETTINGSOVERRIDESENTRY._serialized_start=27027
  _CLONINGINFO_APPSETTINGSOVERRIDESENTRY._serialized_end=27086
  _MANAGEDSERVICEIDENTITY._serialized_start=27089
  _MANAGEDSERVICEIDENTITY._serialized_end=27309
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_start=27248
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_end=27309
  _SERVERFARMSVIRTUALNETWORKCONNECTIONSROUTES._serialized_start=27312
  _SERVERFARMSVIRTUALNETWORKCONNECTIONSROUTES._serialized_end=27505
  _SERVERFARMSVIRTUALNETWORKCONNECTIONSGATEWAYS._serialized_start=27508
  _SERVERFARMSVIRTUALNETWORKCONNECTIONSGATEWAYS._serialized_end=27683
  _SERVERFARMS._serialized_start=27686
  _SERVERFARMS._serialized_end=28586
  _SERVERFARMS_TAGSENTRY._serialized_start=3308
  _SERVERFARMS_TAGSENTRY._serialized_end=3351
  _KUBEENVIRONMENTPROFILE._serialized_start=28588
  _KUBEENVIRONMENTPROFILE._serialized_end=28624
  _HOSTINGENVIRONMENTPROFILE._serialized_start=28626
  _HOSTINGENVIRONMENTPROFILE._serialized_end=28665
  _KUBEENVIRONMENTS._serialized_start=28668
  _KUBEENVIRONMENTS._serialized_end=29361
  _KUBEENVIRONMENTS_TAGSENTRY._serialized_start=3308
  _KUBEENVIRONMENTS_TAGSENTRY._serialized_end=3351
  _CONTAINERAPPSCONFIGURATION._serialized_start=29364
  _CONTAINERAPPSCONFIGURATION._serialized_end=29598
  _ARCCONFIGURATION._serialized_start=29601
  _ARCCONFIGURATION._serialized_end=29917
  _FRONTENDCONFIGURATION._serialized_start=29919
  _FRONTENDCONFIGURATION._serialized_end=29956
  _APPLOGSCONFIGURATION._serialized_start=29959
  _APPLOGSCONFIGURATION._serialized_end=30099
  _LOGANALYTICSCONFIGURATION._serialized_start=30101
  _LOGANALYTICSCONFIGURATION._serialized_end=30169
  _EXTENDEDLOCATION._serialized_start=30171
  _EXTENDEDLOCATION._serialized_end=30203
  _HOSTINGENVIRONMENTSWORKERPOOLS._serialized_start=30206
  _HOSTINGENVIRONMENTSWORKERPOOLS._serialized_end=30474
  _HOSTINGENVIRONMENTSPRIVATEENDPOINTCONNECTIONS._serialized_start=30477
  _HOSTINGENVIRONMENTSPRIVATEENDPOINTCONNECTIONS._serialized_end=30717
  _PRIVATELINKCONNECTIONSTATE._serialized_start=30719
  _PRIVATELINKCONNECTIONSTATE._serialized_end=30810
  _HOSTINGENVIRONMENTSMULTIROLEPOOLS._serialized_start=30813
  _HOSTINGENVIRONMENTSMULTIROLEPOOLS._serialized_end=31084
  _SKUDESCRIPTION._serialized_start=31087
  _SKUDESCRIPTION._serialized_end=31333
  _SKUCAPACITY._serialized_start=31335
  _SKUCAPACITY._serialized_end=31444
  _CAPABILITY._serialized_start=31446
  _CAPABILITY._serialized_end=31503
  _HOSTINGENVIRONMENTSCONFIGURATIONS._serialized_start=31505
  _HOSTINGENVIRONMENTSCONFIGURATIONS._serialized_end=31597
  _HOSTINGENVIRONMENTS._serialized_start=31600
  _HOSTINGENVIRONMENTS._serialized_end=32936
  _HOSTINGENVIRONMENTS_TAGSENTRY._serialized_start=3308
  _HOSTINGENVIRONMENTS_TAGSENTRY._serialized_end=3351
  _VIRTUALNETWORKPROFILE._serialized_start=32938
  _VIRTUALNETWORKPROFILE._serialized_end=32989
  _ASEV3NETWORKINGCONFIGURATION._serialized_start=32992
  _ASEV3NETWORKINGCONFIGURATION._serialized_end=33172
  _CUSTOMDNSSUFFIXCONFIGURATION._serialized_start=33174
  _CUSTOMDNSSUFFIXCONFIGURATION._serialized_end=33301
  _NAMEVALUEPAIR._serialized_start=33303
  _NAMEVALUEPAIR._serialized_end=33347
  _CONTAINERAPPS._serialized_start=33350
  _CONTAINERAPPS._serialized_end=33746
  _CONTAINERAPPS_TAGSENTRY._serialized_start=3308
  _CONTAINERAPPS_TAGSENTRY._serialized_end=3351
  _TEMPLATE._serialized_start=33749
  _TEMPLATE._serialized_end=33956
  _SCALE._serialized_start=33958
  _SCALE._serialized_end=34068
  _SCALERULE._serialized_start=34071
  _SCALERULE._serialized_end=34294
  _HTTPSCALERULE._serialized_start=34297
  _HTTPSCALERULE._serialized_end=34503
  _HTTPSCALERULE_METADATAENTRY._serialized_start=34456
  _HTTPSCALERULE_METADATAENTRY._serialized_end=34503
  _CUSTOMSCALERULE._serialized_start=34506
  _CUSTOMSCALERULE._serialized_end=34730
  _CUSTOMSCALERULE_METADATAENTRY._serialized_start=34456
  _CUSTOMSCALERULE_METADATAENTRY._serialized_end=34503
  _QUEUESCALERULE._serialized_start=34732
  _QUEUESCALERULE._serialized_end=34852
  _SCALERULEAUTH._serialized_start=34854
  _SCALERULEAUTH._serialized_end=34916
  _DAPR._serialized_start=34918
  _DAPR._serialized_end=35043
  _DAPRCOMPONENT._serialized_start=35045
  _DAPRCOMPONENT._serialized_end=35170
  _DAPRMETADATA._serialized_start=35172
  _DAPRMETADATA._serialized_end=35235
  _CONTAINER._serialized_start=35238
  _CONTAINER._serialized_end=35371
  _ENVIRONMENTVAR._serialized_start=35373
  _ENVIRONMENTVAR._serialized_end=35438
  _CONFIGURATION._serialized_start=35441
  _CONFIGURATION._serialized_end=35678
  _SECRET._serialized_start=35680
  _SECRET._serialized_end=35717
  _REGISTRYCREDENTIALS._serialized_start=35719
  _REGISTRYCREDENTIALS._serialized_end=35803
  _INGRESS._serialized_start=35806
  _INGRESS._serialized_end=35962
  _TRAFFICWEIGHT._serialized_start=35964
  _TRAFFICWEIGHT._serialized_end=36043
  _CERTIFICATES._serialized_start=36046
  _CERTIFICATES._serialized_end=36470
  _CERTIFICATES_TAGSENTRY._serialized_start=3308
  _CERTIFICATES_TAGSENTRY._serialized_end=3351
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x61ws/aws_events.proto\x12\x16oak9.tython.aws.events\x1a\x13shared/shared.proto\"l\n\x08\x45ventBus\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x65vent_source_name\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\xab\x01\n\x06\x45vents\x12\x33\n\tevent_bus\x18\x01 \x03(\x0b\x32 .oak9.tython.aws.events.EventBus\x12@\n\x10\x65vent_bus_policy\x18\x02 \x03(\x0b\x32&.oak9.tython.aws.events.EventBusPolicy\x12*\n\x04rule\x18\x03 \x03(\x0b\x32\x1c.oak9.tython.aws.events.Rule\"n\n\x17\x45ventBusPolicyCondition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"\xde\x01\n\x0e\x45ventBusPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x65vent_bus_name\x18\x02 \x01(\t\x12\x42\n\tcondition\x18\x03 \x01(\x0b\x32/.oak9.tython.aws.events.EventBusPolicyCondition\x12\x0e\n\x06\x61\x63tion\x18\x04 \x01(\t\x12\x14\n\x0cstatement_id\x18\x05 \x01(\t\x12\x11\n\tprincipal\x18\x06 \x01(\t\"a\n\x18RuleBatchArrayProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04size\x18\x02 \x01(\x05\"c\n\x16RuleBatchRetryStrategy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08\x61ttempts\x18\x02 \x01(\x05\"\x8c\x02\n\x13RuleBatchParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12J\n\x10\x61rray_properties\x18\x02 \x01(\x0b\x32\x30.oak9.tython.aws.events.RuleBatchArrayProperties\x12\x16\n\x0ejob_definition\x18\x03 \x01(\t\x12\x10\n\x08job_name\x18\x04 \x01(\t\x12\x46\n\x0eretry_strategy\x18\x05 \x01(\x0b\x32..oak9.tython.aws.events.RuleBatchRetryStrategy\"\x96\x01\n\x17RuleAwsVpcConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61ssign_public_ip\x18\x02 \x01(\t\x12\x17\n\x0fsecurity_groups\x18\x03 \x03(\t\x12\x0f\n\x07subnets\x18\x04 \x03(\t\"\xa3\x01\n\x18RuleNetworkConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12N\n\x15\x61ws_vpc_configuration\x18\x02 \x01(\x0b\x32/.oak9.tython.aws.events.RuleAwsVpcConfiguration\"\x8c\x02\n\x11RuleEcsParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05group\x18\x02 \x01(\t\x12\x13\n\x0blaunch_type\x18\x03 \x01(\t\x12O\n\x15network_configuration\x18\x04 \x01(\x0b\x32\x30.oak9.tython.aws.events.RuleNetworkConfiguration\x12\x18\n\x10platform_version\x18\x05 \x01(\t\x12\x12\n\ntask_count\x18\x06 \x01(\x05\x12\x1b\n\x13task_definition_arn\x18\x07 \x01(\t\"\xa8\x03\n\x12RuleHttpParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12[\n\x11header_parameters\x18\x02 \x03(\x0b\x32@.oak9.tython.aws.events.RuleHttpParameters.HeaderParametersEntry\x12\x1d\n\x15path_parameter_values\x18\x03 \x03(\t\x12\x66\n\x17query_string_parameters\x18\x04 \x03(\x0b\x32\x45.oak9.tython.aws.events.RuleHttpParameters.QueryStringParametersEntry\x1a\x37\n\x15HeaderParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a<\n\x1aQueryStringParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf7\x01\n\x14RuleInputTransformer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12X\n\x0finput_paths_map\x18\x02 \x03(\x0b\x32?.oak9.tython.aws.events.RuleInputTransformer.InputPathsMapEntry\x12\x16\n\x0einput_template\x18\x03 \x01(\t\x1a\x34\n\x12InputPathsMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"l\n\x15RuleKinesisParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12partition_key_path\x18\x02 \x01(\t\"l\n\x14RuleRunCommandTarget\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x0e\n\x06values\x18\x03 \x03(\t\"\x9e\x01\n\x18RuleRunCommandParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12I\n\x13run_command_targets\x18\x02 \x03(\x0b\x32,.oak9.tython.aws.events.RuleRunCommandTarget\"f\n\x11RuleSqsParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10message_group_id\x18\x02 \x01(\t\"\x8b\x05\n\nRuleTarget\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03\x61rn\x18\x02 \x01(\t\x12\x45\n\x10\x62\x61tch_parameters\x18\x03 \x01(\x0b\x32+.oak9.tython.aws.events.RuleBatchParameters\x12\x41\n\x0e\x65\x63s_parameters\x18\x04 \x01(\x0b\x32).oak9.tython.aws.events.RuleEcsParameters\x12\x43\n\x0fhttp_parameters\x18\x05 \x01(\x0b\x32*.oak9.tython.aws.events.RuleHttpParameters\x12\n\n\x02id\x18\x06 \x01(\t\x12\r\n\x05input\x18\x07 \x01(\t\x12\x12\n\ninput_path\x18\x08 \x01(\t\x12G\n\x11input_transformer\x18\t \x01(\x0b\x32,.oak9.tython.aws.events.RuleInputTransformer\x12I\n\x12kinesis_parameters\x18\n \x01(\x0b\x32-.oak9.tython.aws.events.RuleKinesisParameters\x12\x10\n\x08role_arn\x18\x0b \x01(\t\x12P\n\x16run_command_parameters\x18\x0c \x01(\x0b\x32\x30.oak9.tython.aws.events.RuleRunCommandParameters\x12\x41\n\x0esqs_parameters\x18\r \x01(\x0b\x32).oak9.tython.aws.events.RuleSqsParameters\"\xe9\x02\n\x04Rule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x16\n\x0e\x65vent_bus_name\x18\x03 \x01(\t\x12\x45\n\revent_pattern\x18\x04 \x03(\x0b\x32..oak9.tython.aws.events.Rule.EventPatternEntry\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x10\n\x08role_arn\x18\x06 \x01(\t\x12\x1b\n\x13schedule_expression\x18\x07 \x01(\t\x12\r\n\x05state\x18\x08 \x01(\t\x12\x33\n\x07targets\x18\t \x03(\x0b\x32\".oak9.tython.aws.events.RuleTarget\x1a\x33\n\x11\x45ventPatternEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RULEHTTPPARAMETERS_HEADERPARAMETERSENTRY._options = None
  _RULEHTTPPARAMETERS_HEADERPARAMETERSENTRY._serialized_options = b'8\001'
  _RULEHTTPPARAMETERS_QUERYSTRINGPARAMETERSENTRY._options = None
  _RULEHTTPPARAMETERS_QUERYSTRINGPARAMETERSENTRY._serialized_options = b'8\001'
  _RULEINPUTTRANSFORMER_INPUTPATHSMAPENTRY._options = None
  _RULEINPUTTRANSFORMER_INPUTPATHSMAPENTRY._serialized_options = b'8\001'
  _RULE_EVENTPATTERNENTRY._options = None
  _RULE_EVENTPATTERNENTRY._serialized_options = b'8\001'
  _EVENTBUS._serialized_start=69
  _EVENTBUS._serialized_end=177
  _EVENTS._serialized_start=180
  _EVENTS._serialized_end=351
  _EVENTBUSPOLICYCONDITION._serialized_start=353
  _EVENTBUSPOLICYCONDITION._serialized_end=463
  _EVENTBUSPOLICY._serialized_start=466
  _EVENTBUSPOLICY._serialized_end=688
  _RULEBATCHARRAYPROPERTIES._serialized_start=690
  _RULEBATCHARRAYPROPERTIES._serialized_end=787
  _RULEBATCHRETRYSTRATEGY._serialized_start=789
  _RULEBATCHRETRYSTRATEGY._serialized_end=888
  _RULEBATCHPARAMETERS._serialized_start=891
  _RULEBATCHPARAMETERS._serialized_end=1159
  _RULEAWSVPCCONFIGURATION._serialized_start=1162
  _RULEAWSVPCCONFIGURATION._serialized_end=1312
  _RULENETWORKCONFIGURATION._serialized_start=1315
  _RULENETWORKCONFIGURATION._serialized_end=1478
  _RULEECSPARAMETERS._serialized_start=1481
  _RULEECSPARAMETERS._serialized_end=1749
  _RULEHTTPPARAMETERS._serialized_start=1752
  _RULEHTTPPARAMETERS._serialized_end=2176
  _RULEHTTPPARAMETERS_HEADERPARAMETERSENTRY._serialized_start=2059
  _RULEHTTPPARAMETERS_HEADERPARAMETERSENTRY._serialized_end=2114
  _RULEHTTPPARAMETERS_QUERYSTRINGPARAMETERSENTRY._serialized_start=2116
  _RULEHTTPPARAMETERS_QUERYSTRINGPARAMETERSENTRY._serialized_end=2176
  _RULEINPUTTRANSFORMER._serialized_start=2179
  _RULEINPUTTRANSFORMER._serialized_end=2426
  _RULEINPUTTRANSFORMER_INPUTPATHSMAPENTRY._serialized_start=2374
  _RULEINPUTTRANSFORMER_INPUTPATHSMAPENTRY._serialized_end=2426
  _RULEKINESISPARAMETERS._serialized_start=2428
  _RULEKINESISPARAMETERS._serialized_end=2536
  _RULERUNCOMMANDTARGET._serialized_start=2538
  _RULERUNCOMMANDTARGET._serialized_end=2646
  _RULERUNCOMMANDPARAMETERS._serialized_start=2649
  _RULERUNCOMMANDPARAMETERS._serialized_end=2807
  _RULESQSPARAMETERS._serialized_start=2809
  _RULESQSPARAMETERS._serialized_end=2911
  _RULETARGET._serialized_start=2914
  _RULETARGET._serialized_end=3565
  _RULE._serialized_start=3568
  _RULE._serialized_end=3929
  _RULE_EVENTPATTERNENTRY._serialized_start=3878
  _RULE_EVENTPATTERNENTRY._serialized_end=3929
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class IamWorkloadIdentityPoolXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___IamWorkloadIdentityPoolXTimeouts = IamWorkloadIdentityPoolXTimeouts

@typing_extensions.final
class IamWorkloadIdentityPool(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    WORKLOAD_IDENTITY_POOL_ID_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    disabled: builtins.bool
    display_name: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    state: builtins.str
    workload_identity_pool_id: builtins.str
    @property
    def timeouts(self) -> global___IamWorkloadIdentityPoolXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        disabled: builtins.bool = ...,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        state: builtins.str = ...,
        workload_identity_pool_id: builtins.str = ...,
        timeouts: global___IamWorkloadIdentityPoolXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "disabled", b"disabled", "display_name", b"display_name", "id", b"id", "name", b"name", "project", b"project", "resource_info", b"resource_info", "state", b"state", "timeouts", b"timeouts", "workload_identity_pool_id", b"workload_identity_pool_id"]) -> None: ...

global___IamWorkloadIdentityPool = IamWorkloadIdentityPool

@typing_extensions.final
class IamWorkloadIdentityPoolProviderXAws(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    account_id: builtins.str
    def __init__(
        self,
        *,
        account_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_id", b"account_id"]) -> None: ...

global___IamWorkloadIdentityPoolProviderXAws = IamWorkloadIdentityPoolProviderXAws

@typing_extensions.final
class IamWorkloadIdentityPoolProviderXOidc(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWED_AUDIENCES_FIELD_NUMBER: builtins.int
    ISSUER_URI_FIELD_NUMBER: builtins.int
    @property
    def allowed_audiences(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    issuer_uri: builtins.str
    def __init__(
        self,
        *,
        allowed_audiences: collections.abc.Iterable[builtins.str] | None = ...,
        issuer_uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_audiences", b"allowed_audiences", "issuer_uri", b"issuer_uri"]) -> None: ...

global___IamWorkloadIdentityPoolProviderXOidc = IamWorkloadIdentityPoolProviderXOidc

@typing_extensions.final
class IamWorkloadIdentityPoolProviderXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___IamWorkloadIdentityPoolProviderXTimeouts = IamWorkloadIdentityPoolProviderXTimeouts

@typing_extensions.final
class IamWorkloadIdentityPoolProvider(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AttributeMappingEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ATTRIBUTE_CONDITION_FIELD_NUMBER: builtins.int
    ATTRIBUTE_MAPPING_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    WORKLOAD_IDENTITY_POOL_ID_FIELD_NUMBER: builtins.int
    WORKLOAD_IDENTITY_POOL_PROVIDER_ID_FIELD_NUMBER: builtins.int
    AWS_FIELD_NUMBER: builtins.int
    OIDC_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    attribute_condition: builtins.str
    @property
    def attribute_mapping(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    description: builtins.str
    disabled: builtins.bool
    display_name: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    state: builtins.str
    workload_identity_pool_id: builtins.str
    workload_identity_pool_provider_id: builtins.str
    @property
    def aws(self) -> global___IamWorkloadIdentityPoolProviderXAws: ...
    @property
    def oidc(self) -> global___IamWorkloadIdentityPoolProviderXOidc: ...
    @property
    def timeouts(self) -> global___IamWorkloadIdentityPoolProviderXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        attribute_condition: builtins.str = ...,
        attribute_mapping: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        description: builtins.str = ...,
        disabled: builtins.bool = ...,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        state: builtins.str = ...,
        workload_identity_pool_id: builtins.str = ...,
        workload_identity_pool_provider_id: builtins.str = ...,
        aws: global___IamWorkloadIdentityPoolProviderXAws | None = ...,
        oidc: global___IamWorkloadIdentityPoolProviderXOidc | None = ...,
        timeouts: global___IamWorkloadIdentityPoolProviderXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["aws", b"aws", "oidc", b"oidc", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attribute_condition", b"attribute_condition", "attribute_mapping", b"attribute_mapping", "aws", b"aws", "description", b"description", "disabled", b"disabled", "display_name", b"display_name", "id", b"id", "name", b"name", "oidc", b"oidc", "project", b"project", "resource_info", b"resource_info", "state", b"state", "timeouts", b"timeouts", "workload_identity_pool_id", b"workload_identity_pool_id", "workload_identity_pool_provider_id", b"workload_identity_pool_provider_id"]) -> None: ...

global___IamWorkloadIdentityPoolProvider = IamWorkloadIdentityPoolProvider
